@@ -37,13 +37,13 @@
 
 #ifdef HAVE_LIBNETTLE
 
-#define IPAD 0x36
-#define OPAD 0x5c
-#define MAX_SHA_DIGEST_SIZE (512/8)
+# define IPAD 0x36
+# define OPAD 0x5c
+# define MAX_SHA_DIGEST_SIZE (512/8)
 
-typedef void (*update_func) (void *, size_t, const uint8_t *);
-typedef void (*digest_func) (void *, size_t, uint8_t *);
-typedef void (*set_key_func) (void *, size_t, const uint8_t *);
+typedef void (*update_func)(void *, size_t, const uint8_t *);
+typedef void (*digest_func)(void *, size_t, uint8_t *);
+typedef void (*set_key_func)(void *, size_t, const uint8_t *);
 
 struct padlock_hmac_ctx {
 	union {
@@ -200,7 +200,6 @@ _hmac_ctx_init(gnutls_mac_algorithm_t algo, struct padlock_hmac_ctx *ctx)
 	return 0;
 }
 
-
 static int wrap_padlock_hmac_init(gnutls_mac_algorithm_t algo, void **_ctx)
 {
 	struct padlock_hmac_ctx *ctx;
@@ -223,12 +222,11 @@ static int wrap_padlock_hmac_init(gnutls_mac_algorithm_t algo, void **_ctx)
 	return 0;
 }
 
-static void *
-wrap_padlock_hmac_copy(const void *_ctx)
+static void *wrap_padlock_hmac_copy(const void *_ctx)
 {
 	struct padlock_hmac_ctx *new_ctx;
-	const struct padlock_hmac_ctx *ctx=_ctx;
-	ptrdiff_t off = (uint8_t *)ctx->ctx_ptr - (uint8_t *)(&ctx->ctx);
+	const struct padlock_hmac_ctx *ctx = _ctx;
+	ptrdiff_t off = (uint8_t *) ctx->ctx_ptr - (uint8_t *) (&ctx->ctx);
 
 	new_ctx = gnutls_malloc(sizeof(struct padlock_hmac_ctx));
 	if (new_ctx == NULL) {
@@ -237,13 +235,12 @@ wrap_padlock_hmac_copy(const void *_ctx)
 	}
 
 	memcpy(new_ctx, ctx, sizeof(*new_ctx));
-	new_ctx->ctx_ptr = (uint8_t *)&new_ctx->ctx + off;
+	new_ctx->ctx_ptr = (uint8_t *) & new_ctx->ctx + off;
 
 	return new_ctx;
 }
 
-static int
-wrap_padlock_hmac_setkey(void *_ctx, const void *key, size_t keylen)
+static int wrap_padlock_hmac_setkey(void *_ctx, const void *key, size_t keylen)
 {
 	struct padlock_hmac_ctx *ctx = _ctx;
 
@@ -280,7 +277,10 @@ wrap_padlock_hmac_output(void *src_ctx, void *digest, size_t digestsize)
 
 static void wrap_padlock_hmac_deinit(void *hd)
 {
-	gnutls_free(hd);
+	struct padlock_hmac_ctx *ctx = hd;
+
+	zeroize_temp_key(ctx, sizeof(*ctx));
+	gnutls_free(ctx);
 }
 
 static int
@@ -316,6 +316,7 @@ wrap_padlock_hmac_fast(gnutls_mac_algorithm_t algo,
 				       pad, text_size + SHA1_DATA_SIZE,
 				       &pad2[SHA1_DATA_SIZE]);
 
+		zeroize_temp_key(pad, text_size + SHA1_DATA_SIZE);
 		gnutls_free(pad);
 
 		memset(pad2, OPAD, SHA1_DATA_SIZE);
@@ -325,6 +326,8 @@ wrap_padlock_hmac_fast(gnutls_mac_algorithm_t algo,
 				       pad2, digest_size + SHA1_DATA_SIZE,
 				       digest);
 
+		zeroize_temp_key(pad2, sizeof(pad2));
+		zeroize_temp_key(hkey, sizeof(hkey));
 	} else {
 		struct padlock_hmac_ctx ctx;
 		int ret;
@@ -339,7 +342,6 @@ wrap_padlock_hmac_fast(gnutls_mac_algorithm_t algo,
 		wrap_padlock_hmac_update(&ctx, text, text_size);
 
 		wrap_padlock_hmac_output(&ctx, digest, ctx.length);
-		wrap_padlock_hmac_deinit(&ctx);
 
 		zeroize_temp_key(&ctx, sizeof(ctx));
 	}
@@ -347,7 +349,7 @@ wrap_padlock_hmac_fast(gnutls_mac_algorithm_t algo,
 	return 0;
 }
 
-const gnutls_crypto_mac_st _gnutls_hmac_sha_padlock = {
+const gnutls_crypto_mac_st _gnutls_hmac_sha_padlock_oneshot = {
 	.init = NULL,
 	.setkey = NULL,
 	.setnonce = NULL,
@@ -357,7 +359,7 @@ const gnutls_crypto_mac_st _gnutls_hmac_sha_padlock = {
 	.fast = wrap_padlock_hmac_fast
 };
 
-const gnutls_crypto_mac_st _gnutls_hmac_sha_padlock_nano = {
+const gnutls_crypto_mac_st _gnutls_hmac_sha_padlock = {
 	.init = wrap_padlock_hmac_init,
 	.setkey = wrap_padlock_hmac_setkey,
 	.setnonce = NULL,
