@@ -32,17 +32,17 @@
 /* Contains PSK code for DHE and ECDHE
  */
 
-#include "auth.h"
-#include "errors.h"
-#include "dh.h"
-#include <auth/psk.h>
-#include "num.h"
-#include "mpi.h"
-#include <state.h>
-#include <auth/dh_common.h>
-#include <auth/ecdhe.h>
-#include <datum.h>
-#include <auth/psk_passwd.h>
+# include "auth.h"
+# include "errors.h"
+# include "dh.h"
+# include <auth/psk.h>
+# include "num.h"
+# include "mpi.h"
+# include <state.h>
+# include <auth/dh_common.h>
+# include <auth/ecdhe.h>
+# include <datum.h>
+# include <auth/psk_passwd.h>
 
 static int
 proc_ecdhe_psk_server_kx(gnutls_session_t session, uint8_t * data,
@@ -56,7 +56,7 @@ static int gen_ecdhe_psk_server_kx(gnutls_session_t session,
 				   gnutls_buffer_st * data);
 static int proc_dhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 				  size_t _data_size);
-#ifdef ENABLE_DHE
+# ifdef ENABLE_DHE
 const mod_auth_st dhe_psk_auth_struct = {
 	"DHE PSK",
 	NULL,
@@ -73,9 +73,9 @@ const mod_auth_st dhe_psk_auth_struct = {
 	NULL,
 	NULL
 };
-#endif
+# endif
 
-#ifdef ENABLE_ECDHE
+# ifdef ENABLE_ECDHE
 const mod_auth_st ecdhe_psk_auth_struct = {
 	"ECDHE PSK",
 	NULL,
@@ -92,7 +92,7 @@ const mod_auth_st ecdhe_psk_auth_struct = {
 	NULL,
 	NULL
 };
-#endif
+# endif
 
 static int
 gen_ecdhe_psk_client_kx(gnutls_session_t session, gnutls_buffer_st * data)
@@ -106,8 +106,7 @@ gen_ecdhe_psk_client_kx(gnutls_session_t session, gnutls_buffer_st * data)
 	    _gnutls_get_cred(session, GNUTLS_CRD_PSK);
 
 	if (cred == NULL)
-		return
-		    gnutls_assert_val(GNUTLS_E_INSUFFICIENT_CREDENTIALS);
+		return gnutls_assert_val(GNUTLS_E_INSUFFICIENT_CREDENTIALS);
 
 	ret = _gnutls_find_psk_key(session, cred, &username, &key, &free);
 	if (ret < 0)
@@ -130,7 +129,7 @@ gen_ecdhe_psk_client_kx(gnutls_session_t session, gnutls_buffer_st * data)
 
 	ret = data->length - init_pos;
 
-      cleanup:
+ cleanup:
 	if (free) {
 		_gnutls_free_datum(&username);
 		_gnutls_free_temp_key_datum(&key);
@@ -151,8 +150,7 @@ gen_dhe_psk_client_kx(gnutls_session_t session, gnutls_buffer_st * data)
 	    _gnutls_get_cred(session, GNUTLS_CRD_PSK);
 
 	if (cred == NULL)
-		return
-		    gnutls_assert_val(GNUTLS_E_INSUFFICIENT_CREDENTIALS);
+		return gnutls_assert_val(GNUTLS_E_INSUFFICIENT_CREDENTIALS);
 
 	ret = _gnutls_find_psk_key(session, cred, &username, &key, &free);
 	if (ret < 0)
@@ -175,7 +173,7 @@ gen_dhe_psk_client_kx(gnutls_session_t session, gnutls_buffer_st * data)
 
 	ret = data->length - init_pos;
 
-      cleanup:
+ cleanup:
 	if (free) {
 		_gnutls_free_datum(&username);
 		_gnutls_free_temp_key_datum(&key);
@@ -189,7 +187,7 @@ gen_dhe_psk_server_kx(gnutls_session_t session, gnutls_buffer_st * data)
 {
 	int ret;
 	gnutls_psk_server_credentials_t cred;
-	gnutls_datum_t hint = {NULL, 0};
+	gnutls_datum_t hint = { NULL, 0 };
 
 	cred = (gnutls_psk_server_credentials_t)
 	    _gnutls_get_cred(session, GNUTLS_CRD_PSK);
@@ -200,13 +198,14 @@ gen_dhe_psk_server_kx(gnutls_session_t session, gnutls_buffer_st * data)
 
 	if ((ret =
 	     _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				   sizeof(psk_auth_info_st), 1)) < 0) {
+				    sizeof(psk_auth_info_st), 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
 
 	ret =
-	    _gnutls_figure_dh_params(session, cred->dh_params, cred->params_func, cred->dh_sec_param);
+	    _gnutls_figure_dh_params(session, cred->dh_params,
+				     cred->params_func, cred->dh_sec_param);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
@@ -221,8 +220,7 @@ gen_dhe_psk_server_kx(gnutls_session_t session, gnutls_buffer_st * data)
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
-	ret =
-	    _gnutls_dh_common_print_server_kx(session, data);
+	ret = _gnutls_dh_common_print_server_kx(session, data);
 	if (ret < 0)
 		gnutls_assert();
 
@@ -234,11 +232,11 @@ gen_ecdhe_psk_server_kx(gnutls_session_t session, gnutls_buffer_st * data)
 {
 	int ret;
 	gnutls_psk_server_credentials_t cred;
-	gnutls_datum_t hint = {NULL, 0};
+	gnutls_datum_t hint = { NULL, 0 };
 
 	if ((ret =
 	     _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				   sizeof(psk_auth_info_st), 1)) < 0) {
+				    sizeof(psk_auth_info_st), 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -261,15 +259,13 @@ gen_ecdhe_psk_server_kx(gnutls_session_t session, gnutls_buffer_st * data)
 		return gnutls_assert_val(ret);
 
 	ret = _gnutls_ecdh_common_print_server_kx(session, data,
-						  get_group
-						  (session));
+						  get_group(session));
 	if (ret < 0)
 		gnutls_assert();
 
 	return ret;
 }
 
-
 static int
 proc_dhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 		       size_t _data_size)
@@ -291,7 +287,7 @@ proc_dhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 
 	if ((ret =
 	     _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				   sizeof(psk_auth_info_st), 1)) < 0) {
+				    sizeof(psk_auth_info_st), 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -316,14 +312,16 @@ proc_dhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 		return GNUTLS_E_ILLEGAL_SRP_USERNAME;
 	}
 
-	memcpy(info->username, username.data, username.size);
-	info->username[username.size] = 0;
+	ret = _gnutls_copy_psk_username(info, username);
+	if (ret < 0)
+		return gnutls_assert_val(ret);
 
 	/* Adjust the data */
 	data += username.size + 2;
 
 	ret =
-	    _gnutls_psk_pwd_find_entry(session, info->username, &psk_key);
+	    _gnutls_psk_pwd_find_entry(session, info->username,
+				       info->username_len, &psk_key);
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
@@ -357,7 +355,7 @@ proc_ecdhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 
 	if ((ret =
 	     _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				   sizeof(psk_auth_info_st), 1)) < 0) {
+				    sizeof(psk_auth_info_st), 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -377,14 +375,14 @@ proc_ecdhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 		return GNUTLS_E_INTERNAL_ERROR;
 	}
 
-
 	if (username.size > MAX_USERNAME_SIZE) {
 		gnutls_assert();
 		return GNUTLS_E_ILLEGAL_SRP_USERNAME;
 	}
 
-	memcpy(info->username, username.data, username.size);
-	info->username[username.size] = 0;
+	ret = _gnutls_copy_psk_username(info, username);
+	if (ret < 0)
+		return gnutls_assert_val(ret);
 
 	/* Adjust the data */
 	data += username.size + 2;
@@ -392,42 +390,19 @@ proc_ecdhe_psk_client_kx(gnutls_session_t session, uint8_t * data,
 	/* should never fail. It will always return a key even if it is
 	 * a random one */
 	ret =
-	    _gnutls_psk_pwd_find_entry(session, info->username, &psk_key);
+	    _gnutls_psk_pwd_find_entry(session, info->username,
+				       info->username_len, &psk_key);
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
 	ret = _gnutls_proc_ecdh_common_client_kx(session, data, data_size,
-						 get_group
-						 (session), &psk_key);
+						 get_group(session), &psk_key);
 
 	_gnutls_free_key_datum(&psk_key);
 
 	return ret;
 }
 
-static int copy_hint(gnutls_session_t session, gnutls_datum_t *hint)
-{
-	psk_auth_info_t info;
-
-	/* copy the hint to the auth info structures
-	 */
-	info = _gnutls_get_auth_info(session, GNUTLS_CRD_PSK);
-	if (info == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INTERNAL_ERROR;
-	}
-
-	if (hint->size > MAX_USERNAME_SIZE) {
-		gnutls_assert();
-		return GNUTLS_E_ILLEGAL_SRP_USERNAME;
-	}
-
-	memcpy(info->hint, hint->data, hint->size);
-	info->hint[hint->size] = 0;
-
-	return 0;
-}
-
 static int
 proc_dhe_psk_server_kx(gnutls_session_t session, uint8_t * data,
 		       size_t _data_size)
@@ -435,12 +410,13 @@ proc_dhe_psk_server_kx(gnutls_session_t session, uint8_t * data,
 
 	int ret;
 	ssize_t data_size = _data_size;
+	psk_auth_info_t info;
 	gnutls_datum_t hint;
 
 	/* set auth_info */
 	if ((ret =
 	     _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				   sizeof(psk_auth_info_st), 1)) < 0) {
+				    sizeof(psk_auth_info_st), 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -459,7 +435,14 @@ proc_dhe_psk_server_kx(gnutls_session_t session, uint8_t * data,
 		return ret;
 	}
 
-	ret = copy_hint(session, &hint);
+	info = _gnutls_get_auth_info(session, GNUTLS_CRD_PSK);
+	if (info == NULL)
+		return gnutls_assert_val(GNUTLS_E_INTERNAL_ERROR);
+
+	if (hint.size > MAX_USERNAME_SIZE)
+		return gnutls_assert_val(GNUTLS_E_ILLEGAL_SRP_USERNAME);
+
+	ret = _gnutls_copy_psk_hint(info, hint);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
@@ -475,12 +458,13 @@ proc_ecdhe_psk_server_kx(gnutls_session_t session, uint8_t * data,
 
 	int ret;
 	ssize_t data_size = _data_size;
+	psk_auth_info_t info;
 	gnutls_datum_t hint;
 
 	/* set auth_info */
 	if ((ret =
 	     _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				   sizeof(psk_auth_info_st), 1)) < 0) {
+				    sizeof(psk_auth_info_st), 1)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -499,7 +483,14 @@ proc_ecdhe_psk_server_kx(gnutls_session_t session, uint8_t * data,
 		return ret;
 	}
 
-	ret = copy_hint(session, &hint);
+	info = _gnutls_get_auth_info(session, GNUTLS_CRD_PSK);
+	if (info == NULL)
+		return gnutls_assert_val(GNUTLS_E_INTERNAL_ERROR);
+
+	if (hint.size > MAX_USERNAME_SIZE)
+		return gnutls_assert_val(GNUTLS_E_ILLEGAL_SRP_USERNAME);
+
+	ret = _gnutls_copy_psk_hint(info, hint);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
