@@ -21,9 +21,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -31,31 +29,30 @@
 
 #ifdef ENABLE_PSK
 
-#include "auth.h"
-#include "dh.h"
-#include "errors.h"
-#include "mpi.h"
-#include "num.h"
-#include "gnutls_int.h"
-#include "pk.h"
-#include "random.h"
-#include <abstract_int.h>
-#include <algorithms.h>
-#include <auth/dh_common.h>
-#include <auth/psk.h>
-#include <auth/psk_passwd.h>
-#include <auth/rsa_common.h>
-#include <cert.h>
-#include <datum.h>
-#include <state.h>
+# include "auth.h"
+# include "dh.h"
+# include "errors.h"
+# include "mpi.h"
+# include "num.h"
+# include "gnutls_int.h"
+# include "pk.h"
+# include "random.h"
+# include <abstract_int.h>
+# include <algorithms.h>
+# include <auth/dh_common.h>
+# include <auth/psk.h>
+# include <auth/psk_passwd.h>
+# include <auth/rsa_common.h>
+# include <cert.h>
+# include <datum.h>
+# include <state.h>
 
 static int _gnutls_gen_rsa_psk_client_kx(gnutls_session_t session,
 					 gnutls_buffer_st * data);
-static int _gnutls_proc_rsa_psk_client_kx(gnutls_session_t, uint8_t *,
-					  size_t);
+static int _gnutls_proc_rsa_psk_client_kx(gnutls_session_t, uint8_t *, size_t);
 static int
 _gnutls_proc_rsa_psk_server_kx(gnutls_session_t session, uint8_t * data,
-			   size_t _data_size);
+			       size_t _data_size);
 
 const mod_auth_st rsa_psk_auth_struct = {
 	"RSA PSK",
@@ -83,7 +80,6 @@ set_rsa_psk_session_key(gnutls_session_t session,
 	size_t rsa_secret_size;
 	int ret;
 
-
 	rsa_secret_size = rsa_secret->size;
 
 	/* set the session key
@@ -103,8 +99,7 @@ set_rsa_psk_session_key(gnutls_session_t session,
 	 * the psk
 	 */
 	_gnutls_write_uint16(rsa_secret_size, session->key.key.data);
-	memcpy(&session->key.key.data[2], rsa_secret->data,
-	       rsa_secret->size);
+	memcpy(&session->key.key.data[2], rsa_secret->data, rsa_secret->size);
 	p = &session->key.key.data[rsa_secret_size + 2];
 	_gnutls_write_uint16(ppsk->size, p);
 	if (ppsk->data != NULL)
@@ -112,7 +107,7 @@ set_rsa_psk_session_key(gnutls_session_t session,
 
 	ret = 0;
 
-      error:
+ error:
 	return ret;
 }
 
@@ -127,8 +122,7 @@ set_rsa_psk_session_key(gnutls_session_t session,
  * } ClientKeyExchange;
  */
 static int
-_gnutls_gen_rsa_psk_client_kx(gnutls_session_t session,
-			      gnutls_buffer_st * data)
+_gnutls_gen_rsa_psk_client_kx(gnutls_session_t session, gnutls_buffer_st * data)
 {
 	cert_auth_info_t auth = session->key.auth_info;
 	gnutls_datum_t sdata;	/* data to send */
@@ -148,8 +142,7 @@ _gnutls_gen_rsa_psk_client_kx(gnutls_session_t session,
 
 	gnutls_datum_t premaster_secret;
 	premaster_secret.size = GNUTLS_MASTER_SIZE;
-	premaster_secret.data =
-	    gnutls_malloc(premaster_secret.size);
+	premaster_secret.data = gnutls_malloc(premaster_secret.size);
 
 	if (premaster_secret.data == NULL) {
 		gnutls_assert();
@@ -158,7 +151,7 @@ _gnutls_gen_rsa_psk_client_kx(gnutls_session_t session,
 
 	/* Generate random */
 	ret = gnutls_rnd(GNUTLS_RND_RANDOM, premaster_secret.data,
-			  premaster_secret.size);
+			 premaster_secret.size);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
@@ -227,16 +220,14 @@ _gnutls_gen_rsa_psk_client_kx(gnutls_session_t session,
 	 */
 	ret =
 	    _gnutls_buffer_append_data_prefix(data, 16,
-					      username.data,
-					      username.size);
+					      username.data, username.size);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
 	}
 
 	ret =
-	    _gnutls_buffer_append_data_prefix(data, 16, sdata.data,
-					      sdata.size);
+	    _gnutls_buffer_append_data_prefix(data, 16, sdata.data, sdata.size);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -244,7 +235,7 @@ _gnutls_gen_rsa_psk_client_kx(gnutls_session_t session,
 
 	ret = data->length - init_pos;
 
-      cleanup:
+ cleanup:
 	_gnutls_free_datum(&sdata);
 	_gnutls_free_temp_key_datum(&premaster_secret);
 	if (free) {
@@ -264,12 +255,14 @@ _gnutls_proc_rsa_psk_client_kx(gnutls_session_t session, uint8_t * data,
 {
 	gnutls_datum_t username;
 	psk_auth_info_t info;
+	gnutls_datum_t plaintext;
 	gnutls_datum_t ciphertext;
 	gnutls_datum_t pwd_psk = { NULL, 0 };
 	int ret, dsize;
+	int randomize_key = 0;
 	ssize_t data_size = _data_size;
 	gnutls_psk_server_credentials_t cred;
-	volatile uint8_t ver_maj, ver_min;
+	gnutls_datum_t premaster_secret = { NULL, 0 };
 
 	cred = (gnutls_psk_server_credentials_t)
 	    _gnutls_get_cred(session, GNUTLS_CRD_PSK);
@@ -280,7 +273,7 @@ _gnutls_proc_rsa_psk_client_kx(gnutls_session_t session, uint8_t * data,
 	}
 
 	ret = _gnutls_auth_info_init(session, GNUTLS_CRD_PSK,
-				    sizeof(psk_auth_info_st), 1);
+				     sizeof(psk_auth_info_st), 1);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
@@ -327,78 +320,96 @@ _gnutls_proc_rsa_psk_client_kx(gnutls_session_t session, uint8_t * data,
 	}
 	ciphertext.size = dsize;
 
-	ver_maj = _gnutls_get_adv_version_major(session);
-	ver_min = _gnutls_get_adv_version_minor(session);
-
-	/* Find the key of this username. A random value will be
-	 * filled in if the key is not found.
-	 */
-	ret = _gnutls_psk_pwd_find_entry(session, info->username,
-					 strlen(info->username), &pwd_psk);
-	if (ret < 0)
-		return gnutls_assert_val(ret);
-
-	/* Allocate memory for premaster secret, and fill in the
-	 * fields except the decryption result.
-	 */
-	session->key.key.size = 2 + GNUTLS_MASTER_SIZE + 2 + pwd_psk.size;
-	session->key.key.data = gnutls_malloc(session->key.key.size);
-	if (session->key.key.data == NULL) {
+	ret =
+	    gnutls_privkey_decrypt_data(session->internals.selected_key, 0,
+					&ciphertext, &plaintext);
+	if (ret < 0 || plaintext.size != GNUTLS_MASTER_SIZE) {
+		/* In case decryption fails then don't inform
+		 * the peer. Just use a random key. (in order to avoid
+		 * attack against pkcs-1 formatting).
+		 */
 		gnutls_assert();
-		_gnutls_free_key_datum(&pwd_psk);
-		/* No need to zeroize, as the secret is not copied in yet */
-		_gnutls_free_datum(&session->key.key);
-		return GNUTLS_E_MEMORY_ERROR;
+		_gnutls_debug_log
+		    ("auth_rsa_psk: Possible PKCS #1 format attack\n");
+		if (ret >= 0) {
+			gnutls_free(plaintext.data);
+		}
+		randomize_key = 1;
+	} else {
+		/* If the secret was properly formatted, then
+		 * check the version number.
+		 */
+		if (_gnutls_get_adv_version_major(session) != plaintext.data[0]
+		    || (session->internals.allow_wrong_pms == 0
+			&& _gnutls_get_adv_version_minor(session) !=
+			plaintext.data[1])) {
+			/* No error is returned here, if the version number check
+			 * fails. We proceed normally.
+			 * That is to defend against the attack described in the paper
+			 * "Attacking RSA-based sessions in SSL/TLS" by Vlastimil Klima,
+			 * Ondej Pokorny and Tomas Rosa.
+			 */
+			gnutls_assert();
+			_gnutls_debug_log
+			    ("auth_rsa: Possible PKCS #1 version check format attack\n");
+		}
 	}
 
-	/* Fallback value when decryption fails. Needs to be unpredictable. */
-	ret = gnutls_rnd(GNUTLS_RND_NONCE, session->key.key.data + 2,
-			 GNUTLS_MASTER_SIZE);
-	if (ret < 0) {
-		gnutls_assert();
-		_gnutls_free_key_datum(&pwd_psk);
-		/* No need to zeroize, as the secret is not copied in yet */
-		_gnutls_free_datum(&session->key.key);
-		return ret;
+	if (randomize_key != 0) {
+		premaster_secret.size = GNUTLS_MASTER_SIZE;
+		premaster_secret.data = gnutls_malloc(premaster_secret.size);
+		if (premaster_secret.data == NULL) {
+			gnutls_assert();
+			return GNUTLS_E_MEMORY_ERROR;
+		}
+
+		/* we do not need strong random numbers here.
+		 */
+		ret = gnutls_rnd(GNUTLS_RND_NONCE, premaster_secret.data,
+				 premaster_secret.size);
+		if (ret < 0) {
+			gnutls_assert();
+			goto cleanup;
+		}
+	} else {
+		premaster_secret.data = plaintext.data;
+		premaster_secret.size = plaintext.size;
 	}
 
-	_gnutls_write_uint16(GNUTLS_MASTER_SIZE, session->key.key.data);
-	_gnutls_write_uint16(pwd_psk.size,
-			     &session->key.key.data[2 + GNUTLS_MASTER_SIZE]);
-	memcpy(&session->key.key.data[2 + GNUTLS_MASTER_SIZE + 2], pwd_psk.data,
-	       pwd_psk.size);
-	_gnutls_free_key_datum(&pwd_psk);
-
-	gnutls_privkey_decrypt_data2(session->internals.selected_key, 0,
-				     &ciphertext, session->key.key.data + 2,
-				     GNUTLS_MASTER_SIZE);
-	/* After this point, any conditional on failure that cause differences
-	 * in execution may create a timing or cache access pattern side
-	 * channel that can be used as an oracle, so tread carefully */
-
-	/* Error handling logic:
-	 * In case decryption fails then don't inform the peer. Just use the
-	 * random key previously generated. (in order to avoid attack against
-	 * pkcs-1 formatting).
-	 *
-	 * If we get version mismatches no error is returned either. We
-	 * proceed normally. This is to defend against the attack described
-	 * in the paper "Attacking RSA-based sessions in SSL/TLS" by
-	 * Vlastimil Klima, Ondej Pokorny and Tomas Rosa.
-	 */
-
 	/* This is here to avoid the version check attack
 	 * discussed above.
 	 */
-	session->key.key.data[2] = ver_maj;
-	session->key.key.data[3] = ver_min;
 
-	return 0;
+	premaster_secret.data[0] = _gnutls_get_adv_version_major(session);
+	premaster_secret.data[1] = _gnutls_get_adv_version_minor(session);
+
+	/* find the key of this username
+	 */
+	ret =
+	    _gnutls_psk_pwd_find_entry(session, info->username,
+				       strlen(info->username), &pwd_psk);
+	if (ret < 0) {
+		gnutls_assert();
+		goto cleanup;
+	}
+
+	ret = set_rsa_psk_session_key(session, &pwd_psk, &premaster_secret);
+	if (ret < 0) {
+		gnutls_assert();
+		goto cleanup;
+	}
+
+	ret = 0;
+ cleanup:
+	_gnutls_free_key_datum(&pwd_psk);
+	_gnutls_free_temp_key_datum(&premaster_secret);
+
+	return ret;
 }
 
 static int
 _gnutls_proc_rsa_psk_server_kx(gnutls_session_t session, uint8_t * data,
-			   size_t _data_size)
+			       size_t _data_size)
 {
 	/* In RSA-PSK the key is calculated elsewhere.
 	 * Moreover, since we only keep a single auth info structure, we cannot
