@@ -15,7 +15,7 @@
  * License for more details.
  * 
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>
  */
 
 #include <config.h>
@@ -104,7 +104,7 @@ int drbg_aes_random(struct drbg_aes_ctx *ctx, unsigned length, uint8_t * dst)
 	uint8_t *p = dst;
 	int ret;
 
-	while(left > 0) {
+	while (left > 0) {
 		p_len = MIN(MAX_DRBG_AES_GENERATE_SIZE, left);
 		ret = drbg_aes_generate(ctx, p_len, p, 0, 0);
 		if (ret == 0)
@@ -119,7 +119,7 @@ int drbg_aes_random(struct drbg_aes_ctx *ctx, unsigned length, uint8_t * dst)
 
 /* we don't use additional input */
 int drbg_aes_generate(struct drbg_aes_ctx *ctx, unsigned length, uint8_t * dst,
-			unsigned add_size, const uint8_t *add)
+		      unsigned add_size, const uint8_t * add)
 {
 	uint8_t tmp[AES_BLOCK_SIZE];
 	uint8_t seed[DRBG_AES_SEED_SIZE];
@@ -136,39 +136,24 @@ int drbg_aes_generate(struct drbg_aes_ctx *ctx, unsigned length, uint8_t * dst,
 			return gnutls_assert_val(0);
 		memcpy(seed, add, add_size);
 		if (add_size != DRBG_AES_SEED_SIZE)
-			memset(&seed[add_size], 0, DRBG_AES_SEED_SIZE - add_size);
+			memset(&seed[add_size], 0,
+			       DRBG_AES_SEED_SIZE - add_size);
 
 		drbg_aes_update(ctx, seed);
 	} else {
 		memset(seed, 0, DRBG_AES_SEED_SIZE);
 	}
 
-	/* Throw the first block generated. FIPS 140-2 requirement (see 
-	 * the continuous random number generator test in 4.9.2)
-	 */
-	if (ctx->prev_block_present == 0) {
-		INCREMENT(sizeof(ctx->v), ctx->v);
-		aes256_encrypt(&ctx->key, AES_BLOCK_SIZE, ctx->prev_block, ctx->v);
-
-		ctx->prev_block_present = 1;
-	}
-
 	/* Perform the actual encryption */
 	for (left = length; left >= AES_BLOCK_SIZE;
 	     left -= AES_BLOCK_SIZE, dst += AES_BLOCK_SIZE) {
-
 		INCREMENT(sizeof(ctx->v), ctx->v);
 		aes256_encrypt(&ctx->key, AES_BLOCK_SIZE, dst, ctx->v);
-
-		memcpy(ctx->prev_block, dst, AES_BLOCK_SIZE);
 	}
 
 	if (left > 0) {		/* partial fill */
-
 		INCREMENT(sizeof(ctx->v), ctx->v);
 		aes256_encrypt(&ctx->key, AES_BLOCK_SIZE, tmp, ctx->v);
-
-		memcpy(ctx->prev_block, tmp, AES_BLOCK_SIZE);
 		memcpy(dst, tmp, left);
 	}
 
