@@ -18,15 +18,14 @@
  * License for more details.
  * 
  * You should have received a copy of the GNU Lesser General Public License
- * along with the nettle library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02111-1301, USA.
+ * along with the nettle library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #if HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
+#include <assert.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -38,22 +37,21 @@
 #include <nettle/bignum.h>
 
 static int
-rsa_provable_prime (mpz_t p,
-			  unsigned *prime_seed_length, void *prime_seed,
-			  unsigned bits,
-			  unsigned seed_length, const void *seed,
-			  mpz_t e,
-			  void *progress_ctx, nettle_progress_func * progress)
+rsa_provable_prime(mpz_t p,
+		   unsigned *prime_seed_length, void *prime_seed,
+		   unsigned bits,
+		   unsigned seed_length, const void *seed,
+		   mpz_t e, void *progress_ctx, nettle_progress_func * progress)
 {
-mpz_t x, t, s, r1, r2, p0, sq;
-int ret;
-unsigned pcounter = 0;
-unsigned iterations;
-unsigned storage_length = 0, i;
-uint8_t *storage = NULL;
-uint8_t pseed[MAX_PVP_SEED_SIZE+1];
-unsigned pseed_length = sizeof(pseed), tseed_length;
-unsigned max = bits*5;
+	mpz_t x, t, s, r1, r2, p0, sq;
+	int ret;
+	unsigned pcounter = 0;
+	unsigned iterations;
+	unsigned storage_length = 0, i;
+	uint8_t *storage = NULL;
+	uint8_t pseed[MAX_PVP_SEED_SIZE + 1];
+	unsigned pseed_length = sizeof(pseed), tseed_length;
+	unsigned max = bits * 5;
 
 	mpz_init(p0);
 	mpz_init(sq);
@@ -66,13 +64,13 @@ unsigned max = bits*5;
 	/* p1 = p2 = 1 */
 
 	ret = st_provable_prime(p0, &pseed_length, pseed,
-				NULL, 1+div_ceil(bits,2), seed_length,
+				NULL, 1 + div_ceil(bits, 2), seed_length,
 				seed, progress_ctx, progress);
 	if (ret == 0) {
 		goto cleanup;
 	}
 
-	iterations = div_ceil(bits, DIGEST_SIZE*8);
+	iterations = div_ceil(bits, DIGEST_SIZE * 8);
 	mpz_set_ui(x, 0);
 
 	if (iterations > 0) {
@@ -84,7 +82,8 @@ unsigned max = bits*5;
 
 		nettle_mpz_set_str_256_u(s, pseed_length, pseed);
 		for (i = 0; i < iterations; i++) {
-			tseed_length = mpz_seed_sizeinbase_256_u(s, pseed_length);
+			tseed_length =
+			    mpz_seed_sizeinbase_256_u(s, pseed_length);
 			if (tseed_length > sizeof(pseed))
 				goto fail;
 			nettle_mpz_get_str_256(tseed_length, pseed, s);
@@ -101,7 +100,7 @@ unsigned max = bits*5;
 
 	/* sq = sqrt(2)*2^(bits-1) */
 	mpz_set_ui(r1, 1);
-	mpz_mul_2exp(r1, r1, 2*bits-1);
+	mpz_mul_2exp(r1, r1, 2 * bits - 1);
 	mpz_sqrt(sq, r1);
 
 	/* r2 = 2^bits - sq */
@@ -135,7 +134,7 @@ unsigned max = bits*5;
 	mpz_mul(p, p, p0);
 	mpz_mul_2exp(p, p, 1);
 
-	/* p = 2(tp2-y)p0p1 + 1*/
+	/* p = 2(tp2-y)p0p1 + 1 */
 	mpz_add_ui(p, p, 1);
 
 	mpz_set_ui(r2, 1);
@@ -168,15 +167,17 @@ unsigned max = bits*5;
 	mpz_gcd(r1, e, r2);
 
 	if (mpz_cmp_ui(r1, 1) == 0) {
-		mpz_set_ui(x, 0); /* a = 0 */
+		mpz_set_ui(x, 0);	/* a = 0 */
 		if (iterations > 0) {
 			for (i = 0; i < iterations; i++) {
-				tseed_length = mpz_seed_sizeinbase_256_u(s, pseed_length);
+				tseed_length =
+				    mpz_seed_sizeinbase_256_u(s, pseed_length);
 				if (tseed_length > sizeof(pseed))
 					goto fail;
 				nettle_mpz_get_str_256(tseed_length, pseed, s);
 
-				hash(&storage[(iterations - i - 1) * DIGEST_SIZE],
+				hash(&storage
+				     [(iterations - i - 1) * DIGEST_SIZE],
 				     tseed_length, pseed);
 				mpz_add_ui(s, s, 1);
 			}
@@ -206,19 +207,24 @@ unsigned max = bits*5;
 			mpz_powm(r1, r2, p0, p);
 			if (mpz_cmp_ui(r1, 1) == 0) {
 				if (prime_seed_length != NULL) {
-					tseed_length = mpz_seed_sizeinbase_256_u(s, pseed_length);
+					tseed_length =
+					    mpz_seed_sizeinbase_256_u(s,
+								      pseed_length);
 					if (tseed_length > sizeof(pseed))
 						goto fail;
 
-					nettle_mpz_get_str_256(tseed_length, pseed, s);
+					nettle_mpz_get_str_256(tseed_length,
+							       pseed, s);
 
 					if (*prime_seed_length < tseed_length) {
-						*prime_seed_length = tseed_length;
+						*prime_seed_length =
+						    tseed_length;
 						goto fail;
 					}
 					*prime_seed_length = tseed_length;
 					if (prime_seed != NULL)
-						memcpy(prime_seed, pseed, tseed_length);
+						memcpy(prime_seed, pseed,
+						       tseed_length);
 				}
 				ret = 1;
 				goto cleanup;
@@ -233,9 +239,9 @@ unsigned max = bits*5;
 	mpz_add_ui(t, t, 1);
 	goto retry;
 
-fail:
+ fail:
 	ret = 0;
-cleanup:
+ cleanup:
 	free(storage);
 	mpz_clear(p0);
 	mpz_clear(sq);
@@ -248,6 +254,32 @@ cleanup:
 	return ret;
 }
 
+/* Return the pre-defined seed length for modulus size, or 0 when the
+ * modulus size is unsupported.
+ */
+static inline unsigned seed_length_for_modulus_size(unsigned modulus_size)
+{
+	switch (modulus_size) {
+	case 2048:		/* SP 800-56B rev 2 Appendix D and FIPS 140-2 IG 7.5 */
+		return 14 * 2;
+	case 3072:		/* SP 800-56B rev 2 Appendix D and FIPS 140-2 IG 7.5 */
+		return 16 * 2;
+	case 4096:		/* SP 800-56B rev 2 Appendix D */
+		return 19 * 2;
+	case 6144:		/* SP 800-56B rev 2 Appendix D */
+		return 22 * 2;
+	case 7680:		/* FIPS 140-2 IG 7.5 */
+		return 24 * 2;
+	case 8192:		/* SP 800-56B rev 2 Appendix D */
+		return 25 * 2;
+	case 15360:		/* FIPS 140-2 IG 7.5 */
+		return 32 * 2;
+	default:
+		return 0;
+	}
+
+}
+
 /* This generates p,q params using the B.3.2.2 algorithm in FIPS 186-4.
  * 
  * The hash function used is SHA384.
@@ -266,10 +298,13 @@ _rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 	int ret;
 	struct dss_params_validation_seeds cert;
 	unsigned l = n_size / 2;
+	unsigned s = seed_length_for_modulus_size(n_size);
 
-	FIPS_RULE(n_size == 2048 && seed_length != 14 * 2, 0, "seed length other than 28 bytes\n");
-	FIPS_RULE(n_size == 3072 && seed_length != 16 * 2, 0, "seed length other than 32 bytes\n");
-	FIPS_RULE(n_size != 2048 && n_size != 3072, 0, "unsupported size for modulus\n");
+	if (!s) {
+		FIPS_RULE(false, 0, "unsupported modulus size\n");
+	}
+
+	FIPS_RULE(seed_length != s, 0, "seed length other than %u bytes\n", s);
 
 	if (!mpz_tstbit(pub->e, 0)) {
 		_gnutls_debug_log("Unacceptable e (it is even)\n");
@@ -297,8 +332,8 @@ _rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 
 	cert.pseed_length = sizeof(cert.pseed);
 	ret = rsa_provable_prime(key->p, &cert.pseed_length, cert.pseed,
-				l, seed_length,
-				seed, pub->e, progress_ctx, progress);
+				 l, seed_length,
+				 seed, pub->e, progress_ctx, progress);
 	if (ret == 0) {
 		goto cleanup;
 	}
@@ -309,18 +344,15 @@ _rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 	do {
 		cert.qseed_length = sizeof(cert.qseed);
 		ret = rsa_provable_prime(key->q, &cert.qseed_length, cert.qseed,
-					l, cert.pseed_length, cert.pseed,
-					pub->e,
-					progress_ctx, progress);
+					 l, cert.pseed_length, cert.pseed,
+					 pub->e, progress_ctx, progress);
 		if (ret == 0) {
 			goto cleanup;
 		}
 
-
 		cert.pseed_length = cert.qseed_length;
 		memcpy(cert.pseed, cert.qseed, cert.qseed_length);
 
-
 		if (mpz_cmp(key->p, key->q) > 0)
 			mpz_sub(t, key->p, key->q);
 		else
@@ -353,12 +385,12 @@ _rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 	}
 
 	/* check whether d > 2^(nlen/2) -- FIPS186-4 5.3.1 */
-	if (mpz_sizeinbase(key->d, 2) < n_size/2) {
+	if (mpz_sizeinbase(key->d, 2) < n_size / 2) {
 		ret = 0;
 		goto cleanup;
 	}
 
-	/* Done! Almost, we must compute the auxillary private values. */
+	/* Done! Almost, we must compute the auxiliary private values. */
 	/* a = d % (p-1) */
 	mpz_fdiv_r(key->a, key->d, p1);
 
@@ -383,10 +415,6 @@ _rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 	return ret;
 }
 
-/* Not entirely accurate but a good precision
- */
-#define SEED_LENGTH(bits) (_gnutls_pk_bits_to_subgroup_bits(bits)/8)
-
 /* This generates p,q params using the B.3.2.2 algorithm in FIPS 186-4.
  * 
  * The hash function used is SHA384.
@@ -398,8 +426,7 @@ rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 			       void *random_ctx, nettle_random_func * random,
 			       void *progress_ctx,
 			       nettle_progress_func * progress,
-			       unsigned *rseed_size,
-			       void *rseed,
+			       unsigned *rseed_size, void *rseed,
 			       /* Desired size of modulo, in bits */
 			       unsigned n_size)
 {
@@ -407,11 +434,10 @@ rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 	unsigned seed_length;
 	int ret;
 
-	FIPS_RULE(n_size != 2048 && n_size != 3072, 0, "size of prime of other than 2048 or 3072\n");
+	seed_length = seed_length_for_modulus_size(n_size);
+	FIPS_RULE(!seed_length, 0, "unsupported modulus size\n");
 
-	seed_length = SEED_LENGTH(n_size);
-	if (seed_length > sizeof(seed))
-		return 0;
+	assert(seed_length <= sizeof(seed));
 
 	random(random_ctx, seed_length, seed);
 
@@ -424,7 +450,7 @@ rsa_generate_fips186_4_keypair(struct rsa_public_key *pub,
 	}
 
 	ret = _rsa_generate_fips186_4_keypair(pub, key, seed_length, seed,
-					       progress_ctx, progress, n_size);
+					      progress_ctx, progress, n_size);
 	gnutls_memset(seed, 0, seed_length);
 	return ret;
 }
