@@ -34,7 +34,8 @@
 #include "db.h"
 
 static int
-pack_ticket(gnutls_session_t session, tls13_ticket_st *ticket, gnutls_datum_t *packed)
+pack_ticket(gnutls_session_t session, tls13_ticket_st * ticket,
+	    gnutls_datum_t * packed)
 {
 	uint8_t *p;
 	gnutls_datum_t state;
@@ -45,8 +46,8 @@ pack_ticket(gnutls_session_t session, tls13_ticket_st *ticket, gnutls_datum_t *p
 		return gnutls_assert_val(ret);
 
 	packed->size = 2 + 4 + 4 +
-		1 + ticket->prf->output_size +
-		1 + ticket->nonce_size + 2 + state.size + 12;
+	    1 + ticket->prf->output_size +
+	    1 + ticket->nonce_size + 2 + state.size + 12;
 
 	packed->data = gnutls_malloc(packed->size);
 	if (!packed->data) {
@@ -93,7 +94,8 @@ pack_ticket(gnutls_session_t session, tls13_ticket_st *ticket, gnutls_datum_t *p
 }
 
 static int
-unpack_ticket(gnutls_session_t session, gnutls_datum_t *packed, tls13_ticket_st *data)
+unpack_ticket(gnutls_session_t session, gnutls_datum_t * packed,
+	      tls13_ticket_st * data)
 {
 	uint32_t age_add, lifetime;
 	struct timespec creation_time;
@@ -105,7 +107,7 @@ unpack_ticket(gnutls_session_t session, gnutls_datum_t *packed, tls13_ticket_st
 	gnutls_mac_algorithm_t kdf;
 	const mac_entry_st *prf;
 	uint8_t *p;
-	ssize_t len;
+	size_t len;
 	uint64_t v;
 	int ret;
 
@@ -193,7 +195,7 @@ unpack_ticket(gnutls_session_t session, gnutls_datum_t *packed, tls13_ticket_st
 }
 
 static int
-generate_session_ticket(gnutls_session_t session, tls13_ticket_st *ticket)
+generate_session_ticket(gnutls_session_t session, tls13_ticket_st * ticket)
 {
 	int ret;
 	gnutls_datum_t packed = { NULL, 0 };
@@ -201,14 +203,17 @@ generate_session_ticket(gnutls_session_t session, tls13_ticket_st *ticket)
 	tls13_ticket_st ticket_data;
 
 	gnutls_gettime(&now);
-	if (session->internals.resumed != RESUME_FALSE) {
+	if (session->internals.resumed) {
 		/* If we are resuming ensure that we don't extend the lifetime
 		 * of the ticket past the original session expiration time */
-		if (now.tv_sec >= session->security_parameters.timestamp + session->internals.expire_time)
-			return GNUTLS_E_INT_RET_0; /* don't send ticket */
+		if (now.tv_sec >=
+		    session->security_parameters.timestamp +
+		    session->internals.expire_time)
+			return GNUTLS_E_INT_RET_0;	/* don't send ticket */
 		else
-			ticket->lifetime = session->security_parameters.timestamp +
-					   session->internals.expire_time - now.tv_sec;
+			ticket->lifetime =
+			    session->security_parameters.timestamp +
+			    session->internals.expire_time - now.tv_sec;
 	} else {
 		/* Set ticket lifetime to the default expiration time */
 		ticket->lifetime = session->internals.expire_time;
@@ -218,10 +223,12 @@ generate_session_ticket(gnutls_session_t session, tls13_ticket_st *ticket)
 	ticket->nonce_size = 4;
 
 	if ((ret = gnutls_rnd(GNUTLS_RND_NONCE,
-			ticket->nonce, ticket->nonce_size)) < 0)
+			      ticket->nonce, ticket->nonce_size)) < 0)
 		return gnutls_assert_val(ret);
 
-	if ((ret = gnutls_rnd(GNUTLS_RND_NONCE, &ticket->age_add, sizeof(uint32_t))) < 0)
+	if ((ret =
+	     gnutls_rnd(GNUTLS_RND_NONCE, &ticket->age_add,
+			sizeof(uint32_t))) < 0)
 		return gnutls_assert_val(ret);
 	/* This is merely to produce the same binder value on
 	 * different endian architectures. */
@@ -239,8 +246,7 @@ generate_session_ticket(gnutls_session_t session, tls13_ticket_st *ticket)
 	ticket_data.nonce_size = ticket->nonce_size;
 	ticket_data.prf = ticket->prf;
 	memcpy(&ticket_data.resumption_master_secret,
-	       session->key.proto.tls13.ap_rms,
-	       ticket->prf->output_size);
+	       session->key.proto.tls13.ap_rms, ticket->prf->output_size);
 
 	ret = pack_ticket(session, &ticket_data, &packed);
 	if (ret < 0)
@@ -254,7 +260,7 @@ generate_session_ticket(gnutls_session_t session, tls13_ticket_st *ticket)
 	return 0;
 }
 
-static int append_nst_extension(void *ctx, gnutls_buffer_st *buf)
+static int append_nst_extension(void *ctx, gnutls_buffer_st * buf)
 {
 	gnutls_session_t session = ctx;
 	int ret;
@@ -271,7 +277,8 @@ static int append_nst_extension(void *ctx, gnutls_buffer_st *buf)
 	return ret;
 }
 
-int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr, unsigned again)
+int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr,
+				  unsigned again)
 {
 	int ret = 0;
 	mbuffer_st *bufel = NULL;
@@ -294,7 +301,7 @@ int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr, unsigne
 		return gnutls_assert_val(0);
 
 	if (again == 0) {
-		for (i=0;i<nr;i++) {
+		for (i = 0; i < nr; i++) {
 			unsigned init_pos;
 
 			memset(&ticket, 0, sizeof(tls13_ticket_st));
@@ -314,27 +321,39 @@ int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr, unsigne
 				goto cleanup;
 			}
 
-			ret = _gnutls_buffer_append_prefix(&buf, 32, ticket.lifetime);
+			ret =
+			    _gnutls_buffer_append_prefix(&buf, 32,
+							 ticket.lifetime);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
 			}
 
-			ret = _gnutls_buffer_append_prefix(&buf, 32, ticket.age_add);
+			ret =
+			    _gnutls_buffer_append_prefix(&buf, 32,
+							 ticket.age_add);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
 			}
 
 			/* append ticket_nonce */
-			ret = _gnutls_buffer_append_data_prefix(&buf, 8, ticket.nonce, ticket.nonce_size);
+			ret =
+			    _gnutls_buffer_append_data_prefix(&buf, 8,
+							      ticket.nonce,
+							      ticket.nonce_size);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
 			}
 
 			/* append ticket */
-			ret = _gnutls_buffer_append_data_prefix(&buf, 16, ticket.ticket.data, ticket.ticket.size);
+			ret =
+			    _gnutls_buffer_append_data_prefix(&buf, 16,
+							      ticket.
+							      ticket.data,
+							      ticket.
+							      ticket.size);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
@@ -350,8 +369,10 @@ int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr, unsigne
 			}
 			init_pos = ret;
 
-			ret = _gnutls_extv_append(&buf, ext_mod_early_data.tls_id, session,
-						  (extv_append_func)append_nst_extension);
+			ret =
+			    _gnutls_extv_append(&buf, ext_mod_early_data.tls_id,
+						session, (extv_append_func)
+						append_nst_extension);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
@@ -366,7 +387,8 @@ int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr, unsigne
 			bufel = _gnutls_buffer_to_mbuffer(&buf);
 
 			ret = _gnutls_send_handshake2(session, bufel,
-						      GNUTLS_HANDSHAKE_NEW_SESSION_TICKET, 1);
+						      GNUTLS_HANDSHAKE_NEW_SESSION_TICKET,
+						      1);
 			if (ret < 0) {
 				gnutls_assert();
 				goto cleanup;
@@ -380,7 +402,7 @@ int _gnutls13_send_session_ticket(gnutls_session_t session, unsigned nr, unsigne
 
 	return ret;
 
-cleanup:
+ cleanup:
 	_gnutls_free_datum(&ticket.ticket);
 	_mbuffer_xfree(&bufel);
 	_gnutls_buffer_clear(&buf);
@@ -388,19 +410,23 @@ cleanup:
 	return ret;
 }
 
-static int parse_nst_extension(void *ctx, unsigned tls_id, const unsigned char *data, unsigned data_size)
+static int parse_nst_extension(void *ctx, unsigned tls_id,
+			       const unsigned char *data, unsigned data_size)
 {
 	gnutls_session_t session = ctx;
 	if (tls_id == ext_mod_early_data.tls_id) {
 		if (data_size < 4)
-			return gnutls_assert_val(GNUTLS_E_TLS_PACKET_DECODING_ERROR);
+			return
+			    gnutls_assert_val
+			    (GNUTLS_E_TLS_PACKET_DECODING_ERROR);
 		session->security_parameters.max_early_data_size =
-			_gnutls_read_uint32(data);
+		    _gnutls_read_uint32(data);
 	}
 	return 0;
 }
 
-int _gnutls13_recv_session_ticket(gnutls_session_t session, gnutls_buffer_st *buf)
+int _gnutls13_recv_session_ticket(gnutls_session_t session,
+				  gnutls_buffer_st * buf)
 {
 	int ret;
 	uint8_t value;
@@ -414,7 +440,8 @@ int _gnutls13_recv_session_ticket(gnutls_session_t session, gnutls_buffer_st *bu
 	_gnutls_free_datum(&ticket->ticket);
 	memset(ticket, 0, sizeof(tls13_ticket_st));
 
-	_gnutls_handshake_log("HSK[%p]: parsing session ticket message\n", session);
+	_gnutls_handshake_log("HSK[%p]: parsing session ticket message\n",
+			      session);
 
 	/* ticket_lifetime */
 	ret = _gnutls_buffer_pop_prefix32(buf, &val, 0);
@@ -449,7 +476,9 @@ int _gnutls13_recv_session_ticket(gnutls_session_t session, gnutls_buffer_st *bu
 		return gnutls_assert_val(ret);
 
 	/* Extensions */
-	ret = _gnutls_extv_parse(session, parse_nst_extension, buf->data, buf->length);
+	ret =
+	    _gnutls_extv_parse(session, parse_nst_extension, buf->data,
+			       buf->length);
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
@@ -464,8 +493,8 @@ int _gnutls13_recv_session_ticket(gnutls_session_t session, gnutls_buffer_st *bu
  * and the KDF ID associated to it.
  */
 int _gnutls13_unpack_session_ticket(gnutls_session_t session,
-		gnutls_datum_t *data,
-		tls13_ticket_st *ticket_data)
+				    gnutls_datum_t * data,
+				    tls13_ticket_st * ticket_data)
 {
 	int ret;
 	gnutls_datum_t decrypted = { NULL, 0 };
@@ -473,6 +502,10 @@ int _gnutls13_unpack_session_ticket(gnutls_session_t session,
 	if (unlikely(data == NULL || ticket_data == NULL))
 		return gnutls_assert_val(GNUTLS_E_INTERNAL_ERROR);
 
+	if (!session->key.stek_initialized) {
+		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
+	}
+
 	/* Check MAC and decrypt ticket */
 	ret = _gnutls_decrypt_session_ticket(session, data, &decrypted);
 	if (ret < 0)
