@@ -47,6 +47,7 @@
  **/
 int gnutls_x509_privkey_init(gnutls_x509_privkey_t * key)
 {
+	*key = NULL;
 	FAIL_IF_LIB_ERROR;
 
 	*key = gnutls_calloc(1, sizeof(gnutls_x509_privkey_int));
@@ -64,7 +65,7 @@ void _gnutls_x509_privkey_reinit(gnutls_x509_privkey_t key)
 	gnutls_pk_params_clear(&key->params);
 	gnutls_pk_params_release(&key->params);
 	/* avoid re-use of fields which may have had some sensible value */
-	memset(&key->params, 0, sizeof(key->params));
+	zeroize_key(&key->params, sizeof(key->params));
 
 	if (key->key)
 		asn1_delete_structure2(&key->key, ASN1_DELETE_FLAG_ZEROIZE);
@@ -98,8 +99,7 @@ void gnutls_x509_privkey_deinit(gnutls_x509_privkey_t key)
  *   negative error value.
  **/
 int
-gnutls_x509_privkey_cpy(gnutls_x509_privkey_t dst,
-			gnutls_x509_privkey_t src)
+gnutls_x509_privkey_cpy(gnutls_x509_privkey_t dst, gnutls_x509_privkey_t src)
 {
 	int ret;
 
@@ -111,9 +111,7 @@ gnutls_x509_privkey_cpy(gnutls_x509_privkey_t dst,
 		return gnutls_assert_val(ret);
 	}
 
-	ret =
-	    _gnutls_asn1_encode_privkey(&dst->key,
-					&dst->params);
+	ret = _gnutls_asn1_encode_privkey(&dst->key, &dst->params);
 	if (ret < 0) {
 		gnutls_assert();
 		gnutls_pk_params_release(&dst->params);
@@ -144,15 +142,14 @@ _gnutls_privkey_decode_pkcs1_rsa_key(const gnutls_datum_t * raw_key,
 
 	result =
 	    _asn1_strict_der_decode(&pkey_asn, raw_key->data, raw_key->size,
-			      NULL);
+				    NULL);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
 		goto error;
 	}
 
 	if (_gnutls_x509_read_int(pkey_asn, "modulus",
-				  &pkey->params.params[0]) < 0)
-	{
+				  &pkey->params.params[0]) < 0) {
 		gnutls_assert();
 		goto error;
 	}
@@ -212,7 +209,7 @@ _gnutls_privkey_decode_pkcs1_rsa_key(const gnutls_datum_t * raw_key,
 
 	return pkey_asn;
 
-      error:
+ error:
 	asn1_delete_structure2(&pkey_asn, ASN1_DELETE_FLAG_ZEROIZE);
 	gnutls_pk_params_clear(&pkey->params);
 	gnutls_pk_params_release(&pkey->params);
@@ -223,8 +220,10 @@ _gnutls_privkey_decode_pkcs1_rsa_key(const gnutls_datum_t * raw_key,
  * an internal structure (gnutls_private_key)
  */
 int
-_gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_key,
-			       gnutls_x509_privkey_t pkey, gnutls_ecc_curve_t curve)
+_gnutls_privkey_decode_ecc_key(asn1_node * pkey_asn,
+			       const gnutls_datum_t * raw_key,
+			       gnutls_x509_privkey_t pkey,
+			       gnutls_ecc_curve_t curve)
 {
 	int ret;
 	unsigned int version;
@@ -248,7 +247,7 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 
 	ret =
 	    _asn1_strict_der_decode(pkey_asn, raw_key->data, raw_key->size,
-			      NULL);
+				    NULL);
 	if (ret != ASN1_SUCCESS) {
 		gnutls_assert();
 		ret = _gnutls_asn2err(ret);
@@ -263,8 +262,7 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 
 	if (version != 1) {
 		_gnutls_debug_log
-		    ("ECC private key version %u is not supported\n",
-		     version);
+		    ("ECC private key version %u is not supported\n", version);
 		gnutls_assert();
 		ret = GNUTLS_E_ECC_UNSUPPORTED_CURVE;
 		goto error;
@@ -275,7 +273,7 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 		oid_size = sizeof(oid);
 		ret =
 		    asn1_read_value(*pkey_asn, "parameters.namedCurve", oid,
-			    &oid_size);
+				    &oid_size);
 		if (ret != ASN1_SUCCESS) {
 			gnutls_assert();
 			ret = _gnutls_asn2err(ret);
@@ -294,7 +292,6 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 		pkey->params.curve = curve;
 	}
 
-
 	/* read the public key */
 	ret = _gnutls_x509_read_value(*pkey_asn, "publicKey", &out);
 	if (ret < 0) {
@@ -317,7 +314,7 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 	/* read the private key */
 	ret =
 	    _gnutls_x509_read_key_int(*pkey_asn, "privateKey",
-				  &pkey->params.params[ECC_K]);
+				      &pkey->params.params[ECC_K]);
 	if (ret < 0) {
 		gnutls_assert();
 		goto error;
@@ -327,7 +324,7 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 
 	return 0;
 
-      error:
+ error:
 	asn1_delete_structure2(pkey_asn, ASN1_DELETE_FLAG_ZEROIZE);
 	gnutls_pk_params_clear(&pkey->params);
 	gnutls_pk_params_release(&pkey->params);
@@ -335,13 +332,12 @@ _gnutls_privkey_decode_ecc_key(asn1_node* pkey_asn, const gnutls_datum_t * raw_k
 
 }
 
-
 static asn1_node
 decode_dsa_key(const gnutls_datum_t * raw_key, gnutls_x509_privkey_t pkey)
 {
 	int result;
 	asn1_node dsa_asn;
-	gnutls_datum_t seed = {NULL,0};
+	gnutls_datum_t seed = { NULL, 0 };
 	char oid[MAX_OID_SIZE];
 	int oid_size;
 
@@ -354,46 +350,40 @@ decode_dsa_key(const gnutls_datum_t * raw_key, gnutls_x509_privkey_t pkey)
 
 	gnutls_pk_params_init(&pkey->params);
 
-
 	result =
 	    _asn1_strict_der_decode(&dsa_asn, raw_key->data, raw_key->size,
-			      NULL);
+				    NULL);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
 		goto error;
 	}
 
-	if (_gnutls_x509_read_int(dsa_asn, "p",
-				  &pkey->params.params[0]) < 0) {
+	if (_gnutls_x509_read_int(dsa_asn, "p", &pkey->params.params[0]) < 0) {
 		gnutls_assert();
 		goto error;
 	}
 	pkey->params.params_nr++;
 
-	if (_gnutls_x509_read_int(dsa_asn, "q",
-				  &pkey->params.params[1]) < 0) {
+	if (_gnutls_x509_read_int(dsa_asn, "q", &pkey->params.params[1]) < 0) {
 		gnutls_assert();
 		goto error;
 	}
 	pkey->params.params_nr++;
 
-	if (_gnutls_x509_read_int(dsa_asn, "g",
-				  &pkey->params.params[2]) < 0) {
+	if (_gnutls_x509_read_int(dsa_asn, "g", &pkey->params.params[2]) < 0) {
 		gnutls_assert();
 		goto error;
 	}
 	pkey->params.params_nr++;
 
-	if (_gnutls_x509_read_int(dsa_asn, "Y",
-				  &pkey->params.params[3]) < 0) {
+	if (_gnutls_x509_read_int(dsa_asn, "Y", &pkey->params.params[3]) < 0) {
 		gnutls_assert();
 		goto error;
 	}
 	pkey->params.params_nr++;
 
 	if (_gnutls_x509_read_key_int(dsa_asn, "priv",
-				      &pkey->params.params[4]) < 0)
-	{
+				      &pkey->params.params[4]) < 0) {
 		gnutls_assert();
 		goto error;
 	}
@@ -417,7 +407,7 @@ decode_dsa_key(const gnutls_datum_t * raw_key, gnutls_x509_privkey_t pkey)
 
 	return dsa_asn;
 
-      error:
+ error:
 	asn1_delete_structure2(&dsa_asn, ASN1_DELETE_FLAG_ZEROIZE);
 	gnutls_pk_params_clear(&pkey->params);
 	gnutls_pk_params_release(&pkey->params);
@@ -425,7 +415,6 @@ decode_dsa_key(const gnutls_datum_t * raw_key, gnutls_x509_privkey_t pkey)
 
 }
 
-
 #define PEM_KEY_DSA "DSA PRIVATE KEY"
 #define PEM_KEY_RSA "RSA PRIVATE KEY"
 #define PEM_KEY_ECC "EC PRIVATE KEY"
@@ -433,13 +422,6 @@ decode_dsa_key(const gnutls_datum_t * raw_key, gnutls_x509_privkey_t pkey)
 
 #define MAX_PEM_HEADER_SIZE 25
 
-#define IF_CHECK_FOR(pemstr, _algo, cptr, bptr, size, key) \
-		if (left > sizeof(pemstr) && memcmp(cptr, pemstr, sizeof(pemstr)-1) == 0) { \
-			result = _gnutls_fbase64_decode(pemstr, bptr, size, &_data); \
-			if (result >= 0) \
-				key->params.algo = _algo; \
-		}
-
 /**
  * gnutls_x509_privkey_import:
  * @key: The data to store the parsed key
@@ -482,37 +464,81 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 		char *ptr;
 		uint8_t *begin_ptr;
 
-		ptr = memmem(data->data, data->size, "PRIVATE KEY-----", sizeof("PRIVATE KEY-----")-1);
+		ptr =
+		    memmem(data->data, data->size, "PRIVATE KEY-----",
+			   sizeof("PRIVATE KEY-----") - 1);
 
 		result = GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
 
 		if (ptr != NULL) {
-			left = data->size - ((ptrdiff_t)ptr - (ptrdiff_t)data->data);
+			left =
+			    data->size - ((ptrdiff_t)ptr -
+					  (ptrdiff_t)data->data);
 
 			if (data->size - left > MAX_PEM_HEADER_SIZE) {
 				ptr -= MAX_PEM_HEADER_SIZE;
 				left += MAX_PEM_HEADER_SIZE;
 			} else {
-				ptr = (char*)data->data;
+				ptr = (char *)data->data;
 				left = data->size;
 			}
 
-			ptr = memmem(ptr, left, "-----BEGIN ", sizeof("-----BEGIN ")-1);
+			ptr =
+			    memmem(ptr, left, "-----BEGIN ",
+				   sizeof("-----BEGIN ") - 1);
 			if (ptr != NULL) {
-				begin_ptr = (uint8_t*)ptr;
-				left = data->size - ((ptrdiff_t)begin_ptr - (ptrdiff_t)data->data);
+				begin_ptr = (uint8_t *) ptr;
+				left =
+				    data->size - ((ptrdiff_t)begin_ptr -
+						  (ptrdiff_t)data->data);
 
-				ptr += sizeof("-----BEGIN ")-1;
+				ptr += sizeof("-----BEGIN ") - 1;
 
-				IF_CHECK_FOR(PEM_KEY_RSA, GNUTLS_PK_RSA, ptr, begin_ptr, left, key)
-				else IF_CHECK_FOR(PEM_KEY_ECC, GNUTLS_PK_EC, ptr, begin_ptr, left, key)
-				else IF_CHECK_FOR(PEM_KEY_DSA, GNUTLS_PK_DSA, ptr, begin_ptr, left, key)
+				if (left > sizeof(PEM_KEY_RSA)
+				    && memcmp(ptr, PEM_KEY_RSA,
+					      sizeof(PEM_KEY_RSA) - 1) == 0) {
+					result =
+					    _gnutls_fbase64_decode(PEM_KEY_RSA,
+								   begin_ptr,
+								   left,
+								   &_data);
+					if (result >= 0)
+						key->params.algo =
+						    GNUTLS_PK_RSA;
+				} else if (left > sizeof(PEM_KEY_ECC)
+					   && memcmp(ptr, PEM_KEY_ECC,
+						     sizeof(PEM_KEY_ECC) - 1) ==
+					   0) {
+					result =
+					    _gnutls_fbase64_decode(PEM_KEY_ECC,
+								   begin_ptr,
+								   left,
+								   &_data);
+					if (result >= 0)
+						key->params.algo = GNUTLS_PK_EC;
+				} else if (left > sizeof(PEM_KEY_DSA)
+					   && memcmp(ptr, PEM_KEY_DSA,
+						     sizeof(PEM_KEY_DSA) - 1) ==
+					   0) {
+					result =
+					    _gnutls_fbase64_decode(PEM_KEY_DSA,
+								   begin_ptr,
+								   left,
+								   &_data);
+					if (result >= 0)
+						key->params.algo =
+						    GNUTLS_PK_DSA;
+				}
 
-				if (key->params.algo == GNUTLS_PK_UNKNOWN && left >= sizeof(PEM_KEY_PKCS8)) {
-					if (memcmp(ptr, PEM_KEY_PKCS8, sizeof(PEM_KEY_PKCS8)-1) == 0) {
+				if (key->params.algo == GNUTLS_PK_UNKNOWN
+				    && left >= sizeof(PEM_KEY_PKCS8)) {
+					if (memcmp
+					    (ptr, PEM_KEY_PKCS8,
+					     sizeof(PEM_KEY_PKCS8) - 1) == 0) {
 						result =
-							_gnutls_fbase64_decode(PEM_KEY_PKCS8,
-								begin_ptr, left, &_data);
+						    _gnutls_fbase64_decode
+						    (PEM_KEY_PKCS8, begin_ptr,
+						     left, &_data);
 						if (result >= 0) {
 							/* signal for PKCS #8 keys */
 							key->params.algo = -1;
@@ -536,11 +562,10 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 	}
 	key->expanded = 1;
 
-	if (key->params.algo == (gnutls_pk_algorithm_t)-1) {
+	if (key->params.algo == (gnutls_pk_algorithm_t) - 1) {
 		result =
 		    gnutls_x509_privkey_import_pkcs8(key, data, format,
-						     NULL,
-						     GNUTLS_PKCS_PLAIN);
+						     NULL, GNUTLS_PKCS_PLAIN);
 		if (result < 0) {
 			gnutls_assert();
 			key->key = NULL;
@@ -550,8 +575,7 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 			goto finish;
 		}
 	} else if (key->params.algo == GNUTLS_PK_RSA) {
-		key->key =
-		    _gnutls_privkey_decode_pkcs1_rsa_key(&_data, key);
+		key->key = _gnutls_privkey_decode_pkcs1_rsa_key(&_data, key);
 		if (key->key == NULL)
 			gnutls_assert();
 	} else if (key->params.algo == GNUTLS_PK_DSA) {
@@ -559,7 +583,8 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 		if (key->key == NULL)
 			gnutls_assert();
 	} else if (key->params.algo == GNUTLS_PK_EC) {
-		result = _gnutls_privkey_decode_ecc_key(&key->key, &_data, key, 0);
+		result =
+		    _gnutls_privkey_decode_ecc_key(&key->key, &_data, key, 0);
 		if (result < 0) {
 			gnutls_assert();
 			key->key = NULL;
@@ -569,8 +594,7 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 		 * succeeds.
 		 */
 		key->params.algo = GNUTLS_PK_RSA;
-		key->key =
-		    _gnutls_privkey_decode_pkcs1_rsa_key(&_data, key);
+		key->key = _gnutls_privkey_decode_pkcs1_rsa_key(&_data, key);
 
 		if (key->key == NULL) {
 			key->params.algo = GNUTLS_PK_DSA;
@@ -578,12 +602,14 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 			if (key->key == NULL) {
 				key->params.algo = GNUTLS_PK_EC;
 				result =
-				    _gnutls_privkey_decode_ecc_key(&key->key, &_data, key, 0);
+				    _gnutls_privkey_decode_ecc_key(&key->key,
+								   &_data, key,
+								   0);
 				if (result < 0) {
 					result =
-					    gnutls_x509_privkey_import_pkcs8(key, data, format,
-									     NULL,
-									     GNUTLS_PKCS_PLAIN);
+					    gnutls_x509_privkey_import_pkcs8
+					    (key, data, format, NULL,
+					     GNUTLS_PKCS_PLAIN);
 					if (result >= 0) {
 						/* there are keys (ed25519) which leave key->key NULL */
 						goto finish;
@@ -593,7 +619,8 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 					gnutls_assert();
 					key->key = NULL;
 
-					if (result == GNUTLS_E_PK_INVALID_PRIVKEY)
+					if (result ==
+					    GNUTLS_E_PK_INVALID_PRIVKEY)
 						goto cleanup;
 				}
 			}
@@ -614,8 +641,10 @@ gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
 	}
 
  cleanup:
-	if (need_free)
+	if (need_free) {
+		zeroize_temp_key(_data.data, _data.size);
 		_gnutls_free_datum(&_data);
+	}
 
 	/* The key has now been decoded.
 	 */
@@ -658,7 +687,7 @@ static int import_pkcs12_privkey(gnutls_x509_privkey_t key,
 	}
 
 	ret = 0;
-      fail:
+ fail:
 
 	gnutls_pkcs12_deinit(p12);
 
@@ -702,45 +731,56 @@ gnutls_x509_privkey_import2(gnutls_x509_privkey_t key,
 		size_t left;
 		char *ptr;
 
-		ptr = memmem(data->data, data->size, "PRIVATE KEY-----", sizeof("PRIVATE KEY-----")-1);
+		ptr =
+		    memmem(data->data, data->size, "PRIVATE KEY-----",
+			   sizeof("PRIVATE KEY-----") - 1);
 
 		if (ptr != NULL) {
-			left = data->size - ((ptrdiff_t)ptr - (ptrdiff_t)data->data);
+			left =
+			    data->size - ((ptrdiff_t)ptr -
+					  (ptrdiff_t)data->data);
 
 			if (data->size - left > 15) {
 				ptr -= 15;
 				left += 15;
 			} else {
-				ptr = (char*)data->data;
+				ptr = (char *)data->data;
 				left = data->size;
 			}
 
-			ptr = memmem(ptr, left, "-----BEGIN ", sizeof("-----BEGIN ")-1);
+			ptr =
+			    memmem(ptr, left, "-----BEGIN ",
+				   sizeof("-----BEGIN ") - 1);
 			if (ptr != NULL) {
-				ptr += sizeof("-----BEGIN ")-1;
-				left = data->size - ((ptrdiff_t)ptr - (ptrdiff_t)data->data);
+				ptr += sizeof("-----BEGIN ") - 1;
+				left =
+				    data->size - ((ptrdiff_t)ptr -
+						  (ptrdiff_t)data->data);
 			}
 
 			if (ptr != NULL && left > sizeof(PEM_KEY_RSA)) {
-				if (memcmp(ptr, PEM_KEY_RSA, sizeof(PEM_KEY_RSA)-1) == 0 ||
-				    memcmp(ptr, PEM_KEY_ECC, sizeof(PEM_KEY_ECC)-1) == 0 ||
-				    memcmp(ptr, PEM_KEY_DSA, sizeof(PEM_KEY_DSA)-1) == 0) {
+				if (memcmp
+				    (ptr, PEM_KEY_RSA,
+				     sizeof(PEM_KEY_RSA) - 1) == 0
+				    || memcmp(ptr, PEM_KEY_ECC,
+					      sizeof(PEM_KEY_ECC) - 1) == 0
+				    || memcmp(ptr, PEM_KEY_DSA,
+					      sizeof(PEM_KEY_DSA) - 1) == 0) {
 					head_enc = 0;
 				}
 			}
 		}
 	}
 
-	if (head_enc == 0 || (password == NULL && !(flags & GNUTLS_PKCS_NULL_PASSWORD))) {
+	if (head_enc == 0
+	    || (password == NULL && !(flags & GNUTLS_PKCS_NULL_PASSWORD))) {
 		ret = gnutls_x509_privkey_import(key, data, format);
 		if (ret >= 0)
 			return ret;
 
-		if (ret < 0) {
-			gnutls_assert();
-			saved_ret = ret;
-			/* fall through to PKCS #8 decoding */
-		}
+		gnutls_assert();
+		saved_ret = ret;
+		/* fall through to PKCS #8 decoding */
 	}
 
 	if ((password != NULL || (flags & GNUTLS_PKCS_NULL_PASSWORD))
@@ -752,15 +792,17 @@ gnutls_x509_privkey_import2(gnutls_x509_privkey_t key,
 
 		if (ret == GNUTLS_E_DECRYPTION_FAILED &&
 		    password == NULL && (!(flags & GNUTLS_PKCS_PLAIN))) {
-		    /* use the callback if any */
-			ret = _gnutls_retrieve_pin(&key->pin, "key:", "", 0, pin, sizeof(pin));
+			/* use the callback if any */
+			ret =
+			    _gnutls_retrieve_pin(&key->pin, "key:", "", 0, pin,
+						 sizeof(pin));
 			if (ret == 0) {
 				password = pin;
 			}
 
 			ret =
 			    gnutls_x509_privkey_import_pkcs8(key, data, format,
-						     password, flags);
+							     password, flags);
 		}
 
 		if (saved_ret == GNUTLS_E_PARSING_ERROR)
@@ -780,6 +822,26 @@ gnutls_x509_privkey_import2(gnutls_x509_privkey_t key,
 				    gnutls_x509_privkey_import_openssl(key,
 								       data,
 								       password);
+
+				if (ret == GNUTLS_E_DECRYPTION_FAILED
+				    && password == NULL && (key->pin.cb
+							    ||
+							    _gnutls_pin_func)) {
+					/* use the callback if any */
+					memset(pin, 0,
+					       GNUTLS_PKCS11_MAX_PIN_LEN);
+					ret =
+					    _gnutls_retrieve_pin(&key->pin,
+								 "key:", "", 0,
+								 pin,
+								 sizeof(pin));
+					if (ret == 0) {
+						ret =
+						    gnutls_x509_privkey_import_openssl
+						    (key, data, pin);
+					}
+				}
+
 				if (ret < 0) {
 					gnutls_assert();
 					goto cleanup;
@@ -793,14 +855,13 @@ gnutls_x509_privkey_import2(gnutls_x509_privkey_t key,
 
 	ret = 0;
 
-      cleanup:
+ cleanup:
 	if (ret == GNUTLS_E_PARSING_ERROR)
 		ret = saved_ret;
 
 	return ret;
 }
 
-
 /**
  * gnutls_x509_privkey_import_rsa_raw:
  * @key: The data to store the parsed key
@@ -872,7 +933,8 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 	gnutls_pk_params_init(&key->params);
 
 	siz = m->size;
-	if (_gnutls_mpi_init_scan_nz(&key->params.params[RSA_MODULUS], m->data, siz)) {
+	if (_gnutls_mpi_init_scan_nz
+	    (&key->params.params[RSA_MODULUS], m->data, siz)) {
 		gnutls_assert();
 		ret = GNUTLS_E_MPI_SCAN_FAILED;
 		goto cleanup;
@@ -880,7 +942,8 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 	key->params.params_nr++;
 
 	siz = e->size;
-	if (_gnutls_mpi_init_scan_nz(&key->params.params[RSA_PUB], e->data, siz)) {
+	if (_gnutls_mpi_init_scan_nz
+	    (&key->params.params[RSA_PUB], e->data, siz)) {
 		gnutls_assert();
 		ret = GNUTLS_E_MPI_SCAN_FAILED;
 		goto cleanup;
@@ -889,7 +952,8 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 
 	if (d) {
 		siz = d->size;
-		if (_gnutls_mpi_init_scan_nz(&key->params.params[RSA_PRIV], d->data, siz)) {
+		if (_gnutls_mpi_init_scan_nz
+		    (&key->params.params[RSA_PRIV], d->data, siz)) {
 			gnutls_assert();
 			ret = GNUTLS_E_MPI_SCAN_FAILED;
 			goto cleanup;
@@ -898,7 +962,8 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 	}
 
 	siz = p->size;
-	if (_gnutls_mpi_init_scan_nz(&key->params.params[RSA_PRIME1], p->data, siz)) {
+	if (_gnutls_mpi_init_scan_nz
+	    (&key->params.params[RSA_PRIME1], p->data, siz)) {
 		gnutls_assert();
 		ret = GNUTLS_E_MPI_SCAN_FAILED;
 		goto cleanup;
@@ -906,7 +971,8 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 	key->params.params_nr++;
 
 	siz = q->size;
-	if (_gnutls_mpi_init_scan_nz(&key->params.params[RSA_PRIME2], q->data, siz)) {
+	if (_gnutls_mpi_init_scan_nz
+	    (&key->params.params[RSA_PRIME2], q->data, siz)) {
 		gnutls_assert();
 		ret = GNUTLS_E_MPI_SCAN_FAILED;
 		goto cleanup;
@@ -915,7 +981,8 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 
 	if (u) {
 		siz = u->size;
-		if (_gnutls_mpi_init_scan_nz(&key->params.params[RSA_COEF], u->data, siz)) {
+		if (_gnutls_mpi_init_scan_nz
+		    (&key->params.params[RSA_COEF], u->data, siz)) {
 			gnutls_assert();
 			ret = GNUTLS_E_MPI_SCAN_FAILED;
 			goto cleanup;
@@ -954,9 +1021,7 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 	key->params.params_nr = RSA_PRIVATE_PARAMS;
 	key->params.algo = GNUTLS_PK_RSA;
 
-	ret =
-	    _gnutls_asn1_encode_privkey(&key->key,
-					&key->params);
+	ret = _gnutls_asn1_encode_privkey(&key->key, &key->params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -964,7 +1029,7 @@ gnutls_x509_privkey_import_rsa_raw2(gnutls_x509_privkey_t key,
 
 	return 0;
 
-      cleanup:
+ cleanup:
 	gnutls_pk_params_clear(&key->params);
 	gnutls_pk_params_release(&key->params);
 	return ret;
@@ -1028,7 +1093,8 @@ gnutls_x509_privkey_import_dsa_raw(gnutls_x509_privkey_t key,
 
 	if (y) {
 		siz = y->size;
-		if (_gnutls_mpi_init_scan_nz(&key->params.params[3], y->data, siz)) {
+		if (_gnutls_mpi_init_scan_nz
+		    (&key->params.params[3], y->data, siz)) {
 			gnutls_assert();
 			ret = GNUTLS_E_MPI_SCAN_FAILED;
 			goto cleanup;
@@ -1042,8 +1108,7 @@ gnutls_x509_privkey_import_dsa_raw(gnutls_x509_privkey_t key,
 		goto cleanup;
 	}
 
-	ret =
-	    _gnutls_pk_fixup(GNUTLS_PK_DSA, GNUTLS_IMPORT, &key->params);
+	ret = _gnutls_pk_fixup(GNUTLS_PK_DSA, GNUTLS_IMPORT, &key->params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1052,9 +1117,7 @@ gnutls_x509_privkey_import_dsa_raw(gnutls_x509_privkey_t key,
 	key->params.algo = GNUTLS_PK_DSA;
 	key->params.params_nr = DSA_PRIVATE_PARAMS;
 
-	ret =
-	    _gnutls_asn1_encode_privkey(&key->key,
-					&key->params);
+	ret = _gnutls_asn1_encode_privkey(&key->key, &key->params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1062,7 +1125,7 @@ gnutls_x509_privkey_import_dsa_raw(gnutls_x509_privkey_t key,
 
 	return 0;
 
-      cleanup:
+ cleanup:
 	gnutls_pk_params_clear(&key->params);
 	gnutls_pk_params_release(&key->params);
 	return ret;
@@ -1131,7 +1194,8 @@ gnutls_x509_privkey_import_ecc_raw(gnutls_x509_privkey_t key,
 			goto cleanup;
 		}
 
-		ret = _gnutls_set_datum(&key->params.raw_priv, k->data, k->size);
+		ret =
+		    _gnutls_set_datum(&key->params.raw_priv, k->data, k->size);
 		if (ret < 0) {
 			gnutls_assert();
 			goto cleanup;
@@ -1166,16 +1230,13 @@ gnutls_x509_privkey_import_ecc_raw(gnutls_x509_privkey_t key,
 
 	key->params.algo = GNUTLS_PK_EC;
 
-	ret =
-	    _gnutls_pk_fixup(GNUTLS_PK_EC, GNUTLS_IMPORT, &key->params);
+	ret = _gnutls_pk_fixup(GNUTLS_PK_EC, GNUTLS_IMPORT, &key->params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
 	}
 
-	ret =
-	    _gnutls_asn1_encode_privkey(&key->key,
-					&key->params);
+	ret = _gnutls_asn1_encode_privkey(&key->key, &key->params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1183,7 +1244,7 @@ gnutls_x509_privkey_import_ecc_raw(gnutls_x509_privkey_t key,
 
 	return 0;
 
-      cleanup:
+ cleanup:
 	gnutls_pk_params_clear(&key->params);
 	gnutls_pk_params_release(&key->params);
 	return ret;
@@ -1263,8 +1324,7 @@ gnutls_x509_privkey_import_gost_raw(gnutls_x509_privkey_t key,
 	}
 	key->params.params_nr++;
 
-	ret =
-	    _gnutls_pk_fixup(key->params.algo, GNUTLS_IMPORT, &key->params);
+	ret = _gnutls_pk_fixup(key->params.algo, GNUTLS_IMPORT, &key->params);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -1272,14 +1332,13 @@ gnutls_x509_privkey_import_gost_raw(gnutls_x509_privkey_t key,
 
 	return 0;
 
-      cleanup:
+ cleanup:
 	gnutls_pk_params_clear(&key->params);
 	gnutls_pk_params_release(&key->params);
 	return ret;
 
 }
 
-
 /**
  * gnutls_x509_privkey_get_pk_algorithm:
  * @key: should contain a #gnutls_x509_privkey_t type
@@ -1334,7 +1393,7 @@ gnutls_x509_privkey_get_pk_algorithm2(gnutls_x509_privkey_t key,
 
 void
 _gnutls_x509_privkey_get_spki_params(gnutls_x509_privkey_t key,
-				     gnutls_x509_spki_st *params)
+				     gnutls_x509_spki_st * params)
 {
 	memcpy(params, &key->params.spki, sizeof(gnutls_x509_spki_st));
 }
@@ -1351,7 +1410,8 @@ _gnutls_x509_privkey_get_spki_params(gnutls_x509_privkey_t key,
  * Returns: Zero on success, or a negative error code on error.
  **/
 int
-gnutls_x509_privkey_get_spki(gnutls_x509_privkey_t key, gnutls_x509_spki_t spki, unsigned int flags)
+gnutls_x509_privkey_get_spki(gnutls_x509_privkey_t key, gnutls_x509_spki_t spki,
+			     unsigned int flags)
 {
 	if (key == NULL) {
 		gnutls_assert();
@@ -1378,7 +1438,8 @@ gnutls_x509_privkey_get_spki(gnutls_x509_privkey_t key, gnutls_x509_spki_t spki,
  * Returns: Zero on success, or a negative error code on error.
  **/
 int
-gnutls_x509_privkey_set_spki(gnutls_x509_privkey_t key, const gnutls_x509_spki_t spki, unsigned int flags)
+gnutls_x509_privkey_set_spki(gnutls_x509_privkey_t key,
+			     const gnutls_x509_spki_t spki, unsigned int flags)
 {
 	gnutls_pk_params_st tparams;
 	int ret;
@@ -1389,15 +1450,15 @@ gnutls_x509_privkey_set_spki(gnutls_x509_privkey_t key, const gnutls_x509_spki_t
 	}
 
 	if (!_gnutls_pk_are_compat(key->params.algo, spki->pk))
-                return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
+		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
 	memcpy(&tparams, &key->params, sizeof(gnutls_pk_params_st));
-	memcpy(&tparams.spki, spki, sizeof (gnutls_x509_spki_st));
+	memcpy(&tparams.spki, spki, sizeof(gnutls_x509_spki_st));
 	ret = _gnutls_x509_check_pubkey_params(&tparams);
 	if (ret < 0)
 		return gnutls_assert_val(ret);
 
-	memcpy(&key->params.spki, spki, sizeof (gnutls_x509_spki_st));
+	memcpy(&key->params.spki, spki, sizeof(gnutls_x509_spki_st));
 
 	key->params.algo = spki->pk;
 
@@ -1440,7 +1501,7 @@ static const char *set_msg(gnutls_x509_privkey_t key)
 int
 gnutls_x509_privkey_export(gnutls_x509_privkey_t key,
 			   gnutls_x509_crt_fmt_t format, void *output_data,
-			   size_t * output_data_size)
+			   size_t *output_data_size)
 {
 	gnutls_datum_t out;
 	int ret;
@@ -1480,8 +1541,7 @@ gnutls_x509_privkey_export(gnutls_x509_privkey_t key,
  **/
 int
 gnutls_x509_privkey_export2(gnutls_x509_privkey_t key,
-			    gnutls_x509_crt_fmt_t format,
-			    gnutls_datum_t * out)
+			    gnutls_x509_crt_fmt_t format, gnutls_datum_t * out)
 {
 	const char *msg;
 	int ret;
@@ -1491,8 +1551,9 @@ gnutls_x509_privkey_export2(gnutls_x509_privkey_t key,
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
-	if (key->key == NULL) { /* can only export in PKCS#8 form */
-		return gnutls_x509_privkey_export2_pkcs8(key, format, NULL, 0, out);
+	if (key->key == NULL) {	/* can only export in PKCS#8 form */
+		return gnutls_x509_privkey_export2_pkcs8(key, format, NULL, 0,
+							 out);
 	}
 
 	msg = set_msg(key);
@@ -1550,10 +1611,9 @@ gnutls_sec_param_t gnutls_x509_privkey_sec_param(gnutls_x509_privkey_t key)
  * Since: 3.0
  **/
 int gnutls_x509_privkey_export_ecc_raw(gnutls_x509_privkey_t key,
-				       gnutls_ecc_curve_t *curve,
-				       gnutls_datum_t *x,
-				       gnutls_datum_t *y,
-				       gnutls_datum_t *k)
+				       gnutls_ecc_curve_t * curve,
+				       gnutls_datum_t * x,
+				       gnutls_datum_t * y, gnutls_datum_t * k)
 {
 	if (key == NULL) {
 		gnutls_assert();
@@ -1590,16 +1650,15 @@ int gnutls_x509_privkey_export_gost_raw(gnutls_x509_privkey_t key,
 					gnutls_digest_algorithm_t * digest,
 					gnutls_gost_paramset_t * paramset,
 					gnutls_datum_t * x,
-					gnutls_datum_t * y,
-					gnutls_datum_t * k)
+					gnutls_datum_t * y, gnutls_datum_t * k)
 {
 	if (key == NULL) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
-	return _gnutls_params_get_gost_raw(&key->params, curve, digest, paramset,
-					   x, y, k, 0);
+	return _gnutls_params_get_gost_raw(&key->params, curve, digest,
+					   paramset, x, y, k, 0);
 }
 
 /**
@@ -1625,7 +1684,8 @@ gnutls_x509_privkey_export_rsa_raw(gnutls_x509_privkey_t key,
 				   gnutls_datum_t * d, gnutls_datum_t * p,
 				   gnutls_datum_t * q, gnutls_datum_t * u)
 {
-	return _gnutls_params_get_rsa_raw(&key->params, m, e, d, p, q, u, NULL, NULL, 0);
+	return _gnutls_params_get_rsa_raw(&key->params, m, e, d, p, q, u, NULL,
+					  NULL, 0);
 }
 
 /**
@@ -1654,10 +1714,10 @@ gnutls_x509_privkey_export_rsa_raw2(gnutls_x509_privkey_t key,
 				    gnutls_datum_t * m, gnutls_datum_t * e,
 				    gnutls_datum_t * d, gnutls_datum_t * p,
 				    gnutls_datum_t * q, gnutls_datum_t * u,
-				    gnutls_datum_t * e1,
-				    gnutls_datum_t * e2)
+				    gnutls_datum_t * e1, gnutls_datum_t * e2)
 {
-	return _gnutls_params_get_rsa_raw(&key->params, m, e, d, p, q, u, e1, e2, 0);
+	return _gnutls_params_get_rsa_raw(&key->params, m, e, d, p, q, u, e1,
+					  e2, 0);
 }
 
 /**
@@ -1721,7 +1781,7 @@ gnutls_x509_privkey_generate(gnutls_x509_privkey_t key,
 			     gnutls_pk_algorithm_t algo, unsigned int bits,
 			     unsigned int flags)
 {
-	return gnutls_x509_privkey_generate2(key, algo, bits, flags, NULL, 0);   
+	return gnutls_x509_privkey_generate2(key, algo, bits, flags, NULL, 0);
 }
 
 /**
@@ -1767,7 +1827,9 @@ gnutls_x509_privkey_generate(gnutls_x509_privkey_t key,
 int
 gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
 			      gnutls_pk_algorithm_t algo, unsigned int bits,
-			      unsigned int flags, const gnutls_keygen_data_st *data, unsigned data_size)
+			      unsigned int flags,
+			      const gnutls_keygen_data_st * data,
+			      unsigned data_size)
 {
 	int ret;
 	unsigned i;
@@ -1780,14 +1842,15 @@ gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
 
 	gnutls_pk_params_init(&key->params);
 
-	for (i=0;i<data_size;i++) {
-		if (data[i].type == GNUTLS_KEYGEN_SEED && data[i].size < sizeof(key->params.seed)) {
+	for (i = 0; i < data_size; i++) {
+		if (data[i].type == GNUTLS_KEYGEN_SEED
+		    && data[i].size < sizeof(key->params.seed)) {
 			key->params.seed_size = data[i].size;
 			memcpy(key->params.seed, data[i].data, data[i].size);
 		} else if (data[i].type == GNUTLS_KEYGEN_DIGEST) {
 			key->params.palgo = data[i].size;
 		} else if (data[i].type == GNUTLS_KEYGEN_SPKI) {
-			tpki = (void*)data[i].data;
+			tpki = (void *)data[i].data;
 		}
 	}
 
@@ -1798,7 +1861,8 @@ gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
 			bits = _gnutls_ecc_bits_to_curve(algo, bits);
 
 		if (gnutls_ecc_curve_get_pk(bits) != algo) {
-			_gnutls_debug_log("curve is incompatible with public key algorithm\n");
+			_gnutls_debug_log
+			    ("curve is incompatible with public key algorithm\n");
 			return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 		}
 	}
@@ -1816,7 +1880,8 @@ gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
 		if ((algo == GNUTLS_PK_GOST_01 && size != 32) ||
 		    (algo == GNUTLS_PK_GOST_12_256 && size != 32) ||
 		    (algo == GNUTLS_PK_GOST_12_512 && size != 64)) {
-			_gnutls_debug_log("curve is incompatible with public key algorithm\n");
+			_gnutls_debug_log
+			    ("curve is incompatible with public key algorithm\n");
 			return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 		}
 
@@ -1840,7 +1905,8 @@ gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
 		const mac_entry_st *me;
 		key->params.spki.pk = GNUTLS_PK_RSA_PSS;
 
-		key->params.spki.rsa_pss_dig = _gnutls_pk_bits_to_sha_hash(bits);
+		key->params.spki.rsa_pss_dig =
+		    _gnutls_pk_bits_to_sha_hash(bits);
 
 		me = hash_to_entry(key->params.spki.rsa_pss_dig);
 		if (unlikely(me == NULL)) {
@@ -1886,7 +1952,7 @@ gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
 
 	return 0;
 
-      cleanup:
+ cleanup:
 	key->params.algo = GNUTLS_PK_UNKNOWN;
 	gnutls_pk_params_clear(&key->params);
 	gnutls_pk_params_release(&key->params);
@@ -1910,7 +1976,9 @@ gnutls_x509_privkey_generate2(gnutls_x509_privkey_t key,
  *
  * Since: 3.5.0
  **/
-int gnutls_x509_privkey_get_seed(gnutls_x509_privkey_t key, gnutls_digest_algorithm_t *digest, void *seed, size_t *seed_size)
+int gnutls_x509_privkey_get_seed(gnutls_x509_privkey_t key,
+				 gnutls_digest_algorithm_t * digest, void *seed,
+				 size_t *seed_size)
 {
 	if (key->params.seed_size == 0)
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
@@ -1931,24 +1999,30 @@ int gnutls_x509_privkey_get_seed(gnutls_x509_privkey_t key, gnutls_digest_algori
 		*digest = key->params.palgo;
 
 	memcpy(seed, key->params.seed, key->params.seed_size);
-	*seed_size = key->params.seed_size; 
+	*seed_size = key->params.seed_size;
 	return 0;
 }
 
 static
 int cmp_rsa_key(gnutls_x509_privkey_t key1, gnutls_x509_privkey_t key2)
 {
-	gnutls_datum_t m1 = {NULL, 0}, e1 = {NULL, 0}, d1 = {NULL, 0}, p1 = {NULL, 0}, q1 = {NULL, 0};
-	gnutls_datum_t m2 = {NULL, 0}, e2 = {NULL, 0}, d2 = {NULL, 0}, p2 = {NULL, 0}, q2 = {NULL, 0};
+	gnutls_datum_t m1 = { NULL, 0 }, e1 = { NULL, 0 }, d1 =
+	    { NULL, 0 }, p1 = { NULL, 0 }, q1 = { NULL, 0 };
+	gnutls_datum_t m2 = { NULL, 0 }, e2 = { NULL, 0 }, d2 =
+	    { NULL, 0 }, p2 = { NULL, 0 }, q2 = { NULL, 0 };
 	int ret;
 
-	ret = gnutls_x509_privkey_export_rsa_raw(key1, &m1, &e1, &d1, &p1, &q1, NULL);
+	ret =
+	    gnutls_x509_privkey_export_rsa_raw(key1, &m1, &e1, &d1, &p1, &q1,
+					       NULL);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
 	}
 
-	ret = gnutls_x509_privkey_export_rsa_raw(key2, &m2, &e2, &d2, &p2, &q2, NULL);
+	ret =
+	    gnutls_x509_privkey_export_rsa_raw(key2, &m2, &e2, &d2, &p2, &q2,
+					       NULL);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -2002,17 +2076,19 @@ int cmp_rsa_key(gnutls_x509_privkey_t key1, gnutls_x509_privkey_t key2)
 static
 int cmp_dsa_key(gnutls_x509_privkey_t key1, gnutls_x509_privkey_t key2)
 {
-	gnutls_datum_t p1 = {NULL, 0}, q1 = {NULL, 0}, g1 = {NULL, 0};
-	gnutls_datum_t p2 = {NULL, 0}, q2 = {NULL, 0}, g2 = {NULL, 0};
+	gnutls_datum_t p1 = { NULL, 0 }, q1 = { NULL, 0 }, g1 = { NULL, 0 };
+	gnutls_datum_t p2 = { NULL, 0 }, q2 = { NULL, 0 }, g2 = { NULL, 0 };
 	int ret;
 
-	ret = gnutls_x509_privkey_export_dsa_raw(key1, &p1, &q1, &g1, NULL, NULL);
+	ret =
+	    gnutls_x509_privkey_export_dsa_raw(key1, &p1, &q1, &g1, NULL, NULL);
 	if (ret < 0) {
 		gnutls_assert();
 		return ret;
 	}
 
-	ret = gnutls_x509_privkey_export_dsa_raw(key2, &p2, &q2, &g2, NULL, NULL);
+	ret =
+	    gnutls_x509_privkey_export_dsa_raw(key2, &p2, &q2, &g2, NULL, NULL);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -2063,7 +2139,9 @@ int cmp_dsa_key(gnutls_x509_privkey_t key1, gnutls_x509_privkey_t key2)
  *
  * Since: 3.5.0
  **/
-int gnutls_x509_privkey_verify_seed(gnutls_x509_privkey_t key, gnutls_digest_algorithm_t digest, const void *seed, size_t seed_size)
+int gnutls_x509_privkey_verify_seed(gnutls_x509_privkey_t key,
+				    gnutls_digest_algorithm_t digest,
+				    const void *seed, size_t seed_size)
 {
 	int ret;
 	gnutls_x509_privkey_t okey;
@@ -2075,7 +2153,8 @@ int gnutls_x509_privkey_verify_seed(gnutls_x509_privkey_t key, gnutls_digest_alg
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
-	if (key->params.algo != GNUTLS_PK_RSA && key->params.algo != GNUTLS_PK_DSA)
+	if (key->params.algo != GNUTLS_PK_RSA
+	    && key->params.algo != GNUTLS_PK_DSA)
 		return gnutls_assert_val(GNUTLS_E_UNIMPLEMENTED_FEATURE);
 
 	ret = gnutls_x509_privkey_get_pk_algorithm2(key, &bits);
@@ -2095,11 +2174,12 @@ int gnutls_x509_privkey_verify_seed(gnutls_x509_privkey_t key, gnutls_digest_alg
 		return gnutls_assert_val(GNUTLS_E_PK_NO_VALIDATION_PARAMS);
 
 	data.type = GNUTLS_KEYGEN_SEED;
-	data.data = (void*)seed;
+	data.data = (void *)seed;
 	data.size = seed_size;
 
 	ret = gnutls_x509_privkey_generate2(okey, key->params.algo, bits,
-					    GNUTLS_PRIVKEY_FLAG_PROVABLE, &data, 1);
+					    GNUTLS_PRIVKEY_FLAG_PROVABLE, &data,
+					    1);
 	if (ret < 0) {
 		gnutls_assert();
 		goto cleanup;
@@ -2110,7 +2190,7 @@ int gnutls_x509_privkey_verify_seed(gnutls_x509_privkey_t key, gnutls_digest_alg
 	else
 		ret = cmp_dsa_key(key, okey);
 
-      cleanup:
+ cleanup:
 	gnutls_x509_privkey_deinit(okey);
 
 	return ret;
@@ -2162,7 +2242,7 @@ int
 gnutls_x509_privkey_get_key_id(gnutls_x509_privkey_t key,
 			       unsigned int flags,
 			       unsigned char *output_data,
-			       size_t * output_data_size)
+			       size_t *output_data_size)
 {
 	int ret;
 
@@ -2181,7 +2261,6 @@ gnutls_x509_privkey_get_key_id(gnutls_x509_privkey_t key,
 	return ret;
 }
 
-
 /**
  * gnutls_x509_privkey_sign_hash:
  * @key: a key
@@ -2214,8 +2293,9 @@ gnutls_x509_privkey_sign_hash(gnutls_x509_privkey_t key,
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
-	if (key->params.algo != GNUTLS_PK_RSA && key->params.algo != GNUTLS_PK_ECDSA &&
-	    key->params.algo != GNUTLS_PK_DSA) {
+	if (key->params.algo != GNUTLS_PK_RSA
+	    && key->params.algo != GNUTLS_PK_ECDSA
+	    && key->params.algo != GNUTLS_PK_DSA) {
 		/* too primitive API - use only with legacy types */
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
@@ -2263,10 +2343,10 @@ gnutls_x509_privkey_sign_data(gnutls_x509_privkey_t key,
 			      gnutls_digest_algorithm_t digest,
 			      unsigned int flags,
 			      const gnutls_datum_t * data,
-			      void *signature, size_t * signature_size)
+			      void *signature, size_t *signature_size)
 {
 	gnutls_privkey_t privkey;
-	gnutls_datum_t sig = {NULL, 0};
+	gnutls_datum_t sig = { NULL, 0 };
 	int ret;
 
 	ret = gnutls_privkey_init(&privkey);
@@ -2294,7 +2374,7 @@ gnutls_x509_privkey_sign_data(gnutls_x509_privkey_t key,
 	*signature_size = sig.size;
 	memcpy(signature, sig.data, sig.size);
 
-cleanup:
+ cleanup:
 	_gnutls_free_datum(&sig);
 	gnutls_privkey_deinit(privkey);
 	return ret;
@@ -2322,9 +2402,7 @@ int gnutls_x509_privkey_fix(gnutls_x509_privkey_t key)
 	if (key->key) {
 		asn1_delete_structure2(&key->key, ASN1_DELETE_FLAG_ZEROIZE);
 
-		ret =
-		    _gnutls_asn1_encode_privkey(&key->key,
-						&key->params);
+		ret = _gnutls_asn1_encode_privkey(&key->key, &key->params);
 		if (ret < 0) {
 			gnutls_assert();
 			return ret;
@@ -2350,8 +2428,8 @@ int gnutls_x509_privkey_fix(gnutls_x509_privkey_t key)
  *
  **/
 void gnutls_x509_privkey_set_pin_function(gnutls_x509_privkey_t privkey,
-				      gnutls_pin_callback_t fn,
-				      void *userdata)
+					  gnutls_pin_callback_t fn,
+					  void *userdata)
 {
 	privkey->pin.cb = fn;
 	privkey->pin.data = userdata;
@@ -2374,4 +2452,3 @@ void gnutls_x509_privkey_set_flags(gnutls_x509_privkey_t key,
 {
 	key->flags |= flags;
 }
-
