@@ -38,8 +38,8 @@
  */
 
 int _gnutls_read_pbkdf1_params(const uint8_t * data, int data_size,
-		       struct pbkdf2_params *kdf_params,
-		       struct pbe_enc_params *enc_params)
+			       struct pbkdf2_params *kdf_params,
+			       struct pbe_enc_params *enc_params)
 {
 	asn1_node pasn = NULL;
 	int len;
@@ -49,17 +49,16 @@ int _gnutls_read_pbkdf1_params(const uint8_t * data, int data_size,
 	memset(enc_params, 0, sizeof(*enc_params));
 
 	if ((result =
-		     asn1_create_element(_gnutls_get_pkix(),
-					 "PKIX1.pkcs-5-PBE-params",
-					 &pasn)) != ASN1_SUCCESS) {
+	     asn1_create_element(_gnutls_get_pkix(),
+				 "PKIX1.pkcs-5-PBE-params",
+				 &pasn)) != ASN1_SUCCESS) {
 		gnutls_assert();
 		return _gnutls_asn2err(result);
 	}
 
 	/* Decode the parameters.
 	 */
-	result =
-	    _asn1_strict_der_decode(&pasn, data, data_size, NULL);
+	result = _asn1_strict_der_decode(&pasn, data, data_size, NULL);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
 		ret = _gnutls_asn2err(result);
@@ -68,21 +67,20 @@ int _gnutls_read_pbkdf1_params(const uint8_t * data, int data_size,
 
 	ret =
 	    _gnutls_x509_read_uint(pasn, "iterationCount",
-			   &kdf_params->iter_count);
+				   &kdf_params->iter_count);
 	if (ret < 0) {
 		gnutls_assert();
 		goto error;
 	}
 
-	if (kdf_params->iter_count >= MAX_ITER_COUNT || kdf_params->iter_count == 0) {
+	if (kdf_params->iter_count >= MAX_ITER_COUNT
+	    || kdf_params->iter_count == 0) {
 		ret = gnutls_assert_val(GNUTLS_E_ILLEGAL_PARAMETER);
 		goto error;
 	}
 
 	len = sizeof(kdf_params->salt);
-	result =
-	    asn1_read_value(pasn, "salt",
-		    kdf_params->salt, &len);
+	result = asn1_read_value(pasn, "salt", kdf_params->salt, &len);
 	if (result != ASN1_SUCCESS) {
 		gnutls_assert();
 		ret = _gnutls_asn2err(result);
@@ -105,7 +103,8 @@ int _gnutls_read_pbkdf1_params(const uint8_t * data, int data_size,
 }
 
 static void pbkdf1_md5(const char *password, unsigned password_len,
-	const uint8_t salt[8], unsigned iter_count, unsigned key_size, uint8_t *key)
+		       const uint8_t salt[8], unsigned iter_count,
+		       unsigned key_size, uint8_t * key)
 {
 	struct md5_ctx ctx;
 	uint8_t tmp[16];
@@ -114,10 +113,10 @@ static void pbkdf1_md5(const char *password, unsigned password_len,
 	if (key_size > sizeof(tmp))
 		abort();
 
-	for (i=0;i<iter_count;i++) {
+	for (i = 0; i < iter_count; i++) {
 		md5_init(&ctx);
-		if (i==0) {
-			md5_update(&ctx, password_len, (uint8_t*)password);
+		if (i == 0) {
+			md5_update(&ctx, password_len, (uint8_t *) password);
 			md5_update(&ctx, 8, salt);
 			md5_digest(&ctx, 16, tmp);
 		} else {
@@ -132,15 +131,15 @@ static void pbkdf1_md5(const char *password, unsigned password_len,
 
 int
 _gnutls_decrypt_pbes1_des_md5_data(const char *password,
-			   unsigned password_len,
-			   const struct pbkdf2_params *kdf_params,
-			   const struct pbe_enc_params *enc_params,
-			   const gnutls_datum_t *encrypted_data,
-			   gnutls_datum_t *decrypted_data)
+				   unsigned password_len,
+				   const struct pbkdf2_params *kdf_params,
+				   const struct pbe_enc_params *enc_params,
+				   const gnutls_datum_t * encrypted_data,
+				   gnutls_datum_t * decrypted_data)
 {
 	int result;
 	gnutls_datum_t dkey, d_iv;
-	cipher_hd_st ch;
+	gnutls_cipher_hd_t ch;
 	uint8_t key[16];
 	const unsigned block_size = 8;
 
@@ -152,37 +151,43 @@ _gnutls_decrypt_pbes1_des_md5_data(const char *password,
 
 	/* generate the key
 	 */
-	pbkdf1_md5(password, password_len, kdf_params->salt, kdf_params->iter_count, sizeof(key), key);
+	pbkdf1_md5(password, password_len, kdf_params->salt,
+		   kdf_params->iter_count, sizeof(key), key);
 
 	dkey.data = key;
 	dkey.size = 8;
 	d_iv.data = &key[8];
 	d_iv.size = 8;
-	result =
-	    _gnutls_cipher_init(&ch, cipher_to_entry(GNUTLS_CIPHER_DES_CBC),
-				&dkey, &d_iv, 0);
-	if (result < 0)
+	result = gnutls_cipher_init(&ch, GNUTLS_CIPHER_DES_CBC, &dkey, &d_iv);
+	if (result < 0) {
+		_gnutls_switch_fips_state(GNUTLS_FIPS140_OP_ERROR);
 		return gnutls_assert_val(result);
+	}
+	_gnutls_switch_fips_state(GNUTLS_FIPS140_OP_NOT_APPROVED);
 
-	result = _gnutls_cipher_decrypt(&ch, encrypted_data->data, encrypted_data->size);
+	result =
+	    gnutls_cipher_decrypt(ch, encrypted_data->data,
+				  encrypted_data->size);
 	if (result < 0) {
 		gnutls_assert();
 		goto error;
 	}
 
-	if ((int)encrypted_data->size - encrypted_data->data[encrypted_data->size - 1] < 0) {
+	if ((int)encrypted_data->size -
+	    encrypted_data->data[encrypted_data->size - 1] < 0) {
 		gnutls_assert();
 		result = GNUTLS_E_ILLEGAL_PARAMETER;
 		goto error;
 	}
 
 	decrypted_data->data = encrypted_data->data;
-	decrypted_data->size = encrypted_data->size - encrypted_data->data[encrypted_data->size - 1];
+	decrypted_data->size =
+	    encrypted_data->size - encrypted_data->data[encrypted_data->size -
+							1];
 
 	result = 0;
  error:
-	_gnutls_cipher_deinit(&ch);
+	gnutls_cipher_deinit(ch);
 
 	return result;
 }
-
