@@ -23,7 +23,7 @@
 /* Work around problem reported in
    <https://permalink.gmane.org/gmane.comp.lib.gnulib.bugs/15755>.*/
 #if GETTIMEOFDAY_CLOBBERS_LOCALTIME
-#undef localtime
+# undef localtime
 #endif
 
 #include <getpass.h>
@@ -41,11 +41,11 @@
 #ifndef _WIN32
 # include <signal.h>
 #else
-#include <ws2tcpip.h>
+# include <ws2tcpip.h>
 #endif
 
 #ifdef ENABLE_PKCS11
-#include <gnutls/pkcs11.h>
+# include <gnutls/pkcs11.h>
 #endif
 
 #define SU(x) (x!=NULL?x:"Unknown")
@@ -97,7 +97,7 @@ const char *raw_to_hex(const unsigned char *raw, size_t raw_size)
 const char *raw_to_base64(const unsigned char *raw, size_t raw_size)
 {
 	static char buf[1024];
-	gnutls_datum_t data = {(unsigned char*)raw, raw_size};
+	gnutls_datum_t data = { (unsigned char *)raw, raw_size };
 	size_t buf_size;
 	int ret;
 
@@ -115,7 +115,8 @@ const char *raw_to_base64(const unsigned char *raw, size_t raw_size)
 }
 
 static void
-print_x509_info(gnutls_session_t session, FILE *out, int flag, int print_cert, int print_crt_status)
+print_x509_info(gnutls_session_t session, FILE * out, int flag, int print_cert,
+		int print_crt_status)
 {
 	gnutls_x509_crt_t crt;
 	const gnutls_datum_t *cert_list;
@@ -131,7 +132,7 @@ print_x509_info(gnutls_session_t session, FILE *out, int flag, int print_cert, i
 
 	log_msg(out, "- Certificate type: X.509\n");
 	log_msg(out, "- Got a certificate list of %d certificates.\n",
-	       cert_list_size);
+		cert_list_size);
 
 	for (j = 0; j < cert_list_size; j++) {
 		gnutls_datum_t cinfo;
@@ -166,14 +167,14 @@ print_x509_info(gnutls_session_t session, FILE *out, int flag, int print_cert, i
 
 			ret =
 			    gnutls_x509_crt_export2(crt,
-						   GNUTLS_X509_FMT_PEM, &pem);
+						    GNUTLS_X509_FMT_PEM, &pem);
 			if (ret < 0) {
 				fprintf(stderr, "Encoding error: %s\n",
 					gnutls_strerror(ret));
 				return;
 			}
 
-			log_msg(out, "\n%s\n", (char*)pem.data);
+			log_msg(out, "\n%s\n", (char *)pem.data);
 
 			gnutls_free(pem.data);
 		}
@@ -183,7 +184,8 @@ print_x509_info(gnutls_session_t session, FILE *out, int flag, int print_cert, i
 }
 
 static void
-print_rawpk_info(gnutls_session_t session, FILE *out, int flag, int print_cert, int print_crt_status)
+print_rawpk_info(gnutls_session_t session, FILE * out, int flag, int print_cert,
+		 int print_crt_status)
 {
 	gnutls_pcert_st pk_cert;
 	gnutls_pk_algorithm_t pk_algo;
@@ -199,14 +201,13 @@ print_rawpk_info(gnutls_session_t session, FILE *out, int flag, int print_cert,
 	}
 
 	log_msg(out, "- Certificate type: Raw Public Key\n");
-	log_msg(out, "- Got %d Raw public-key(s).\n",
-	       cert_list_size);
+	log_msg(out, "- Got %d Raw public-key(s).\n", cert_list_size);
 
-
-	ret = gnutls_pcert_import_rawpk_raw(&pk_cert, cert_list, GNUTLS_X509_FMT_DER, 0, 0);
+	ret =
+	    gnutls_pcert_import_rawpk_raw(&pk_cert, cert_list,
+					  GNUTLS_X509_FMT_DER, 0, 0);
 	if (ret < 0) {
-		fprintf(stderr, "Decoding error: %s\n",
-			gnutls_strerror(ret));
+		fprintf(stderr, "Decoding error: %s\n", gnutls_strerror(ret));
 		return;
 	}
 
@@ -218,23 +219,28 @@ print_rawpk_info(gnutls_session_t session, FILE *out, int flag, int print_cert,
 	if (print_cert) {
 		gnutls_datum_t pem;
 
-		ret = gnutls_pubkey_export2(pk_cert.pubkey, GNUTLS_X509_FMT_PEM, &pem);
+		ret =
+		    gnutls_pubkey_export2(pk_cert.pubkey, GNUTLS_X509_FMT_PEM,
+					  &pem);
 		if (ret < 0) {
 			fprintf(stderr, "Encoding error: %s\n",
 				gnutls_strerror(ret));
-			return;
+			goto cleanup;
 		}
 
-		log_msg(out, "\n%s\n", (char*)pem.data);
+		log_msg(out, "\n%s\n", (char *)pem.data);
 
 		gnutls_free(pem.data);
 	}
 
+ cleanup:
+	gnutls_pcert_deinit(&pk_cert);
 }
 
 /* returns false (0) if not verified, or true (1) otherwise 
  */
-int cert_verify(gnutls_session_t session, const char *hostname, const char *purpose)
+int cert_verify(gnutls_session_t session, const char *hostname,
+		const char *purpose)
 {
 	int rc;
 	unsigned int status = 0;
@@ -247,13 +253,13 @@ int cert_verify(gnutls_session_t session, const char *hostname, const char *purp
 
 	if (hostname) {
 		data[elements].type = GNUTLS_DT_DNS_HOSTNAME;
-		data[elements].data = (void*)hostname;
+		data[elements].data = (void *)hostname;
 		elements++;
 	}
 
 	if (purpose) {
 		data[elements].type = GNUTLS_DT_KEY_PURPOSE_OID;
-		data[elements].data = (void*)purpose;
+		data[elements].data = (void *)purpose;
 		elements++;
 	}
 
@@ -265,7 +271,7 @@ int cert_verify(gnutls_session_t session, const char *hostname, const char *purp
 
 	if (rc < 0) {
 		log_msg(stdout, "- Could not verify certificate (err: %s)\n",
-		       gnutls_strerror(rc));
+			gnutls_strerror(rc));
 		return 0;
 	}
 
@@ -273,8 +279,9 @@ int cert_verify(gnutls_session_t session, const char *hostname, const char *purp
 	rc = gnutls_certificate_verification_status_print(status, type,
 							  &out, 0);
 	if (rc < 0) {
-		log_msg(stdout, "- Could not print verification flags (err: %s)\n",
-		       gnutls_strerror(rc));
+		log_msg(stdout,
+			"- Could not print verification flags (err: %s)\n",
+			gnutls_strerror(rc));
 		return 0;
 	}
 
@@ -293,8 +300,7 @@ int cert_verify(gnutls_session_t session, const char *hostname, const char *purp
 
 /* Parse input string and set certificate compression methods */
 int compress_cert_set_methods(gnutls_session_t session,
-			      const char **strings,
-			      size_t n_strings)
+			      const char **strings, size_t n_strings)
 {
 	int ret = 0;
 	gnutls_compression_method_t *methods;
@@ -309,7 +315,8 @@ int compress_cert_set_methods(gnutls_session_t session,
 
 	methods = reallocarray(NULL, n_strings, sizeof(*methods));
 	if (!methods) {
-		fprintf(stderr, "Could not set certificate compression methods: %s\n",
+		fprintf(stderr,
+			"Could not set certificate compression methods: %s\n",
 			gnutls_strerror(ret));
 		return GNUTLS_E_MEMORY_ERROR;
 	}
@@ -323,14 +330,17 @@ int compress_cert_set_methods(gnutls_session_t session,
 		}
 	}
 
-	ret = gnutls_compress_certificate_set_methods(session, methods, n_strings);
+	ret =
+	    gnutls_compress_certificate_set_methods(session, methods,
+						    n_strings);
 	if (ret < 0) {
-		fprintf(stderr, "Could not set certificate compression methods: %s\n",
+		fprintf(stderr,
+			"Could not set certificate compression methods: %s\n",
 			gnutls_strerror(ret));
 		goto cleanup;
 	}
 
-cleanup:
+ cleanup:
 	free(methods);
 
 #pragma GCC diagnostic pop
@@ -338,8 +348,7 @@ cleanup:
 	return ret;
 }
 
-static void
-print_dh_info(gnutls_session_t session, const char *str, int print)
+static void print_dh_info(gnutls_session_t session, const char *str, int print)
 {
 #if defined(ENABLE_DHE) || defined(ENABLE_ANON)
 	unsigned group;
@@ -360,11 +369,11 @@ print_dh_info(gnutls_session_t session, const char *str, int print)
 
 	log_msg(stdout, "- %sDiffie-Hellman parameters\n", str);
 	log_msg(stdout, " - Using prime: %d bits\n",
-	       gnutls_dh_get_prime_bits(session));
+		gnutls_dh_get_prime_bits(session));
 	log_msg(stdout, " - Secret key: %d bits\n",
-	       gnutls_dh_get_secret_bits(session));
+		gnutls_dh_get_secret_bits(session));
 	log_msg(stdout, " - Peer's public key: %d bits\n",
-	       gnutls_dh_get_peers_public_bits(session));
+		gnutls_dh_get_peers_public_bits(session));
 
 	ret = gnutls_dh_get_group(session, &raw_gen, &raw_prime);
 	if (ret) {
@@ -378,22 +387,17 @@ print_dh_info(gnutls_session_t session, const char *str, int print)
 		goto out;
 	}
 
-	ret =
-	    gnutls_dh_params_import_raw(dh_params, &raw_prime,
-						&raw_gen);
+	ret = gnutls_dh_params_import_raw(dh_params, &raw_prime, &raw_gen);
 	if (ret) {
-		fprintf(stderr, "gnutls_dh_params_import_raw %d\n",
-			ret);
+		fprintf(stderr, "gnutls_dh_params_import_raw %d\n", ret);
 		goto out;
 	}
 
 	ret = gnutls_dh_params_export_pkcs3(dh_params,
 					    GNUTLS_X509_FMT_PEM,
-					    params_data,
-					    &params_data_size);
+					    params_data, &params_data_size);
 	if (ret != GNUTLS_E_SHORT_MEMORY_BUFFER) {
-		fprintf(stderr,
-			"gnutls_dh_params_export_pkcs3 %d\n", ret);
+		fprintf(stderr, "gnutls_dh_params_export_pkcs3 %d\n", ret);
 		goto out;
 	}
 
@@ -405,19 +409,16 @@ print_dh_info(gnutls_session_t session, const char *str, int print)
 
 	ret = gnutls_dh_params_export_pkcs3(dh_params,
 					    GNUTLS_X509_FMT_PEM,
-					    params_data,
-					    &params_data_size);
+					    params_data, &params_data_size);
 	if (ret) {
-		fprintf(stderr,
-			"gnutls_dh_params_export_pkcs3-2 %d\n",
-			ret);
+		fprintf(stderr, "gnutls_dh_params_export_pkcs3-2 %d\n", ret);
 		goto out;
 	}
 
 	log_msg(stdout, " - PKCS#3 format:\n\n%.*s\n",
-	       (int) params_data_size, params_data);
+		(int)params_data_size, params_data);
 
-      out:
+ out:
 	gnutls_free(params_data);
 	gnutls_free(raw_prime.data);
 	gnutls_free(raw_gen.data);
@@ -425,7 +426,8 @@ print_dh_info(gnutls_session_t session, const char *str, int print)
 #endif
 }
 
-static void print_ecdh_info(gnutls_session_t session, const char *str, int print)
+static void print_ecdh_info(gnutls_session_t session, const char *str,
+			    int print)
 {
 	int curve;
 
@@ -436,12 +438,56 @@ static void print_ecdh_info(gnutls_session_t session, const char *str, int print
 
 	curve = gnutls_ecc_curve_get(session);
 
-	log_msg(stdout, " - Using curve: %s\n", gnutls_ecc_curve_get_name(curve));
+	log_msg(stdout, " - Using curve: %s\n",
+		gnutls_ecc_curve_get_name(curve));
 	log_msg(stdout, " - Curve size: %d bits\n",
-	       gnutls_ecc_curve_get_size(curve) * 8);
+		gnutls_ecc_curve_get_size(curve) * 8);
 
 }
 
+struct channel_binding_request {
+	gnutls_channel_binding_t type;
+	const char *name;
+};
+
+static void print_channel_bindings(gnutls_session_t session, int print)
+{
+	static const struct channel_binding_request requests[] = {
+		{GNUTLS_CB_TLS_UNIQUE, "tls-unique"},
+		{GNUTLS_CB_TLS_SERVER_END_POINT, "tls-server-end-point"},
+		{GNUTLS_CB_TLS_EXPORTER, "tls-exporter"}
+	};
+	size_t i;
+
+	if (!print) {
+		return;
+	}
+
+	log_msg(stdout, "- Channel bindings\n");
+	for (i = 0; i < sizeof(requests) / sizeof(requests[0]); i++) {
+		gnutls_datum_t cb;
+		int rc;
+
+		rc = gnutls_session_channel_binding(session,
+						    requests[i].type, &cb);
+		if (rc == GNUTLS_E_CHANNEL_BINDING_NOT_AVAILABLE) {
+			log_msg(stdout, " - '%s': not available\n",
+				requests[i].name);
+		} else if (rc < 0) {
+			fprintf(stderr, " - '%s': error: %s\n",
+				requests[i].name, gnutls_strerror(rc));
+		} else {
+			size_t j;
+
+			log_msg(stdout, " - '%s': ", requests[i].name);
+			for (j = 0; j < cb.size; j++)
+				log_msg(stdout, "%02x", cb.data[j]);
+			log_msg(stdout, "\n");
+			gnutls_free(cb.data);
+		}
+	}
+}
+
 int print_info(gnutls_session_t session, int verbose, int flags)
 {
 	const char *tmp;
@@ -453,6 +499,7 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 	gnutls_datum_t p;
 	char *desc;
 	gnutls_protocol_t version;
+	gnutls_transport_ktls_enable_flags_t ktls_flags;
 	int rc;
 
 	desc = gnutls_session_get_desc(session);
@@ -463,7 +510,7 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 	gnutls_session_get_id(session, session_id, &session_id_size);
 	if (session_id_size > 0) {
 		log_msg(stdout, "- Session ID: %s\n",
-		       raw_to_string(session_id, session_id_size));
+			raw_to_string(session_id, session_id_size));
 	}
 
 	/* print the key exchange's algorithm name
@@ -486,8 +533,9 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 		 * side.
 		 */
 		if (gnutls_srp_server_get_username(session) != NULL)
-			log_msg(stdout, "- SRP authentication. Connected as '%s'\n",
-			       gnutls_srp_server_get_username(session));
+			log_msg(stdout,
+				"- SRP authentication. Connected as '%s'\n",
+				gnutls_srp_server_get_username(session));
 		break;
 #endif
 #ifdef ENABLE_PSK
@@ -496,12 +544,13 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 		 */
 		if (gnutls_psk_client_get_hint(session) != NULL)
 			log_msg(stdout, "- PSK authentication. PSK hint '%s'\n",
-			       gnutls_psk_client_get_hint(session));
+				gnutls_psk_client_get_hint(session));
 		/* This returns NULL in client side.
 		 */
 		if (gnutls_psk_server_get_username(session) != NULL)
-			log_msg(stdout, "- PSK authentication. Connected as '%s'\n",
-			       gnutls_psk_server_get_username(session));
+			log_msg(stdout,
+				"- PSK authentication. Connected as '%s'\n",
+				gnutls_psk_server_get_username(session));
 		if (kx == GNUTLS_KX_DHE_PSK)
 			print_dh_info(session, "Ephemeral ", verbose);
 		if (kx == GNUTLS_KX_ECDHE_PSK)
@@ -521,28 +570,32 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 			if (gnutls_server_name_get
 			    (session, dns, &dns_size, &type, 0) == 0) {
 				log_msg(stdout, "- Given server name[%d]: %s\n",
-				       type, dns);
+					type, dns);
 			}
 		}
 
-		if ((flags & P_WAIT_FOR_CERT) && gnutls_certificate_get_ours(session) == 0)
+		if ((flags & P_WAIT_FOR_CERT)
+		    && gnutls_certificate_get_ours(session) == 0)
 			log_msg(stdout, "- No certificate was sent to peer\n");
 
-		if (flags& P_PRINT_CERT)
-			print_cert_info(session, verbose, (flags&P_PRINT_CERT));
+		if (flags & P_PRINT_CERT)
+			print_cert_info(session, verbose,
+					(flags & P_PRINT_CERT));
 
 		if (kx == GNUTLS_KX_DHE_RSA || kx == GNUTLS_KX_DHE_DSS)
 			print_dh_info(session, "Ephemeral ", verbose);
 		else if (kx == GNUTLS_KX_ECDHE_RSA
 			 || kx == GNUTLS_KX_ECDHE_ECDSA)
 			print_ecdh_info(session, "Ephemeral ", verbose);
+		break;
+	default:
+		log_msg(stdout, "- Unknown credential type %d\n", cred);
+		break;
 	}
 
-
 	if (verbose) {
 		version = gnutls_protocol_get_version(session);
-		tmp =
-		    SU(gnutls_protocol_get_name(version));
+		tmp = SU(gnutls_protocol_get_name(version));
 		log_msg(stdout, "- Version: %s\n", tmp);
 
 		if (version < GNUTLS_TLS1_3) {
@@ -573,15 +626,19 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 	}
 
 	log_msg(stdout, "- Options:");
-	if (gnutls_session_ext_master_secret_status(session)!=0)
+	if (gnutls_session_ext_master_secret_status(session) != 0)
 		log_msg(stdout, " extended master secret,");
-	if (gnutls_safe_renegotiation_status(session)!=0)
+	if (gnutls_safe_renegotiation_status(session) != 0)
 		log_msg(stdout, " safe renegotiation,");
-	if (gnutls_session_etm_status(session)!=0)
+	if (gnutls_session_etm_status(session) != 0)
 		log_msg(stdout, " EtM,");
 #ifdef ENABLE_OCSP
-	if (gnutls_ocsp_status_request_is_checked(session, GNUTLS_OCSP_SR_IS_AVAIL)!=0) {
-		log_msg(stdout, " OCSP status request%s,", gnutls_ocsp_status_request_is_checked(session,0)!=0?"":"[ignored]");
+	if (gnutls_ocsp_status_request_is_checked
+	    (session, GNUTLS_OCSP_SR_IS_AVAIL) != 0) {
+		log_msg(stdout, " OCSP status request%s,",
+			gnutls_ocsp_status_request_is_checked(session,
+							      0) !=
+			0 ? "" : "[ignored]");
 	}
 #endif
 	log_msg(stdout, "\n");
@@ -590,33 +647,28 @@ int print_info(gnutls_session_t session, int verbose, int flags)
 	rc = gnutls_srtp_get_selected_profile(session, &srtp_profile);
 	if (rc == 0)
 		log_msg(stdout, "- SRTP profile: %s\n",
-		       gnutls_srtp_get_profile_name(srtp_profile));
+			gnutls_srtp_get_profile_name(srtp_profile));
 #endif
 
 #ifdef ENABLE_ALPN
 	rc = gnutls_alpn_get_selected_protocol(session, &p);
 	if (rc == 0)
-		log_msg(stdout, "- Application protocol: %.*s\n", p.size, p.data);
+		log_msg(stdout, "- Application protocol: %.*s\n", p.size,
+			p.data);
 #endif
 
-	if (verbose) {
-		gnutls_datum_t cb;
+	print_channel_bindings(session, verbose);
 
-		rc = gnutls_session_channel_binding(session,
-						    GNUTLS_CB_TLS_UNIQUE,
-						    &cb);
-		if (rc)
-			fprintf(stderr, "Channel binding error: %s\n",
-				gnutls_strerror(rc));
-		else {
-			size_t i;
-
-			log_msg(stdout, "- Channel binding 'tls-unique': ");
-			for (i = 0; i < cb.size; i++)
-				log_msg(stdout, "%02x", cb.data[i]);
-			log_msg(stdout, "\n");
-			gnutls_free(cb.data);
-		}
+	ktls_flags = gnutls_transport_is_ktls_enabled(session);
+	if (ktls_flags != 0) {
+		log_msg(stdout, "- KTLS: %s\n",
+			(ktls_flags & GNUTLS_KTLS_DUPLEX) ==
+			GNUTLS_KTLS_DUPLEX ? "send, recv" : (ktls_flags &
+							     GNUTLS_KTLS_SEND)
+			==
+			GNUTLS_KTLS_SEND ? "send" : (ktls_flags &
+						     GNUTLS_KTLS_RECV) ==
+			GNUTLS_KTLS_RECV ? "recv" : "unknown");
 	}
 
 	fflush(stdout);
@@ -629,7 +681,8 @@ void print_cert_info(gnutls_session_t session, int verbose, int print_cert)
 	print_cert_info2(session, verbose, stdout, print_cert);
 }
 
-void print_cert_info2(gnutls_session_t session, int verbose, FILE *out, int print_cert)
+void print_cert_info2(gnutls_session_t session, int verbose, FILE * out,
+		      int print_cert)
 {
 	int flag, print_crt_status = 0;
 
@@ -645,10 +698,12 @@ void print_cert_info2(gnutls_session_t session, int verbose, FILE *out, int prin
 
 	switch (gnutls_certificate_type_get2(session, GNUTLS_CTYPE_PEERS)) {
 	case GNUTLS_CRT_X509:
-		print_x509_info(session, out, flag, print_cert, print_crt_status);
+		print_x509_info(session, out, flag, print_cert,
+				print_crt_status);
 		break;
 	case GNUTLS_CRT_RAWPK:
-		print_rawpk_info(session, out, flag, print_cert, print_crt_status);
+		print_rawpk_info(session, out, flag, print_cert,
+				 print_crt_status);
 		break;
 	default:
 		break;
@@ -678,15 +733,15 @@ void print_list(const char *priorities, int verbose)
 			if (ret == GNUTLS_E_INVALID_REQUEST)
 				fprintf(stderr, "Syntax error at: %s\n", err);
 			else
-				fprintf(stderr, "Error in priorities: %s\n", gnutls_strerror(ret));
+				fprintf(stderr, "Error in priorities: %s\n",
+					gnutls_strerror(ret));
 			exit(1);
 		}
 
 		for (i = 0;; i++) {
 			ret =
 			    gnutls_priority_get_cipher_suite_index(pcache,
-								   i,
-								   &idx);
+								   i, &idx);
 			if (ret == GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE)
 				break;
 			if (ret == GNUTLS_E_UNKNOWN_CIPHER_SUITE)
@@ -698,9 +753,9 @@ void print_list(const char *priorities, int verbose)
 
 			if (name != NULL)
 				log_msg(stdout, "%-50s\t0x%02x, 0x%02x\t%s\n",
-				       name, (unsigned char) id[0],
-				       (unsigned char) id[1],
-				       gnutls_protocol_get_name(version));
+					name, (unsigned char)id[0],
+					(unsigned char)id[1],
+					gnutls_protocol_get_name(version));
 		}
 
 		log_msg(stdout, "\n");
@@ -708,17 +763,17 @@ void print_list(const char *priorities, int verbose)
 		{
 			ret =
 			    gnutls_priority_certificate_type_list2(pcache,
-								  &list,
-								  GNUTLS_CTYPE_CLIENT);
+								   &list,
+								   GNUTLS_CTYPE_CLIENT);
 
 			log_msg(stdout, "Certificate types: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "CTYPE-%s",
-				       gnutls_certificate_type_get_name
-				       (list[i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_certificate_type_get_name
+					(list[i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -732,10 +787,10 @@ void print_list(const char *priorities, int verbose)
 			log_msg(stdout, "Protocols: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "VERS-%s",
-				       gnutls_protocol_get_name(list[i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_protocol_get_name(list[i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -748,10 +803,10 @@ void print_list(const char *priorities, int verbose)
 			log_msg(stdout, "Ciphers: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "%s",
-				       gnutls_cipher_get_name(list[i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_cipher_get_name(list[i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -764,10 +819,10 @@ void print_list(const char *priorities, int verbose)
 			log_msg(stdout, "MACs: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "%s",
-				       gnutls_mac_get_name(list[i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_mac_get_name(list[i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -780,10 +835,10 @@ void print_list(const char *priorities, int verbose)
 			log_msg(stdout, "Key Exchange Algorithms: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "%s",
-				       gnutls_kx_get_name(list[i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_kx_get_name(list[i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -791,16 +846,15 @@ void print_list(const char *priorities, int verbose)
 		}
 
 		{
-			ret =
-			    gnutls_priority_group_list(pcache, &list);
+			ret = gnutls_priority_group_list(pcache, &list);
 
 			log_msg(stdout, "Groups: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "GROUP-%s",
-				       gnutls_group_get_name(list[i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_group_get_name(list[i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -813,11 +867,11 @@ void print_list(const char *priorities, int verbose)
 			log_msg(stdout, "PK-signatures: ");
 			if (ret == 0)
 				log_msg(stdout, "none\n");
-			for (i = 0; i < (unsigned) ret; i++) {
+			for (i = 0; i < (unsigned)ret; i++) {
 				log_msg(stdout, "SIGN-%s",
-				       gnutls_sign_algorithm_get_name(list
-								      [i]));
-				if (i + 1 != (unsigned) ret)
+					gnutls_sign_algorithm_get_name(list
+								       [i]));
+				if (i + 1 != (unsigned)ret)
 					log_msg(stdout, ", ");
 				else
 					log_msg(stdout, "\n");
@@ -832,12 +886,13 @@ void print_list(const char *priorities, int verbose)
 	for (i = 0; (name = gnutls_cipher_suite_info
 		     (i, id, &kx, &cipher, &mac, &version)); i++) {
 		log_msg(stdout, "%-50s\t0x%02x, 0x%02x\t%s\n",
-		       name,
-		       (unsigned char) id[0], (unsigned char) id[1],
-		       gnutls_protocol_get_name(version));
+			name,
+			(unsigned char)id[0], (unsigned char)id[1],
+			gnutls_protocol_get_name(version));
 		if (verbose)
 			log_msg
-			    (stdout, "\tKey exchange: %s\n\tCipher: %s\n\tMAC: %s\n\n",
+			    (stdout,
+			     "\tKey exchange: %s\n\tCipher: %s\n\tMAC: %s\n\n",
 			     gnutls_kx_get_name(kx),
 			     gnutls_cipher_get_name(cipher),
 			     gnutls_mac_get_name(mac));
@@ -851,7 +906,7 @@ void print_list(const char *priorities, int verbose)
 		log_msg(stdout, "Certificate types: ");
 		for (; *p; p++) {
 			log_msg(stdout, "CTYPE-%s",
-			       gnutls_certificate_type_get_name(*p));
+				gnutls_certificate_type_get_name(*p));
 			if (*(p + 1))
 				log_msg(stdout, ", ");
 			else
@@ -864,7 +919,8 @@ void print_list(const char *priorities, int verbose)
 
 		log_msg(stdout, "Protocols: ");
 		for (; *p; p++) {
-			log_msg(stdout, "VERS-%s", gnutls_protocol_get_name(*p));
+			log_msg(stdout, "VERS-%s",
+				gnutls_protocol_get_name(*p));
 			if (*(p + 1))
 				log_msg(stdout, ", ");
 			else
@@ -930,7 +986,8 @@ void print_list(const char *priorities, int verbose)
 
 		log_msg(stdout, "Compression: ");
 		for (; *p; p++) {
-			log_msg(stdout, "COMP-%s", gnutls_compression_get_name(*p));
+			log_msg(stdout, "COMP-%s",
+				gnutls_compression_get_name(*p));
 			if (*(p + 1))
 				log_msg(stdout, ", ");
 			else
@@ -970,7 +1027,7 @@ void print_list(const char *priorities, int verbose)
 		log_msg(stdout, "PK-signatures: ");
 		for (; *p; p++) {
 			log_msg(stdout, "SIGN-%s",
-			       gnutls_sign_algorithm_get_name(*p));
+				gnutls_sign_algorithm_get_name(*p));
 			if (*(p + 1))
 				log_msg(stdout, ", ");
 			else
@@ -1016,7 +1073,8 @@ print_key_material(gnutls_session_t session, const char *label, size_t size)
 	gnutls_free(hex.data);
 }
 
-int check_command(gnutls_session_t session, const char *str, unsigned no_cli_cert)
+int check_command(gnutls_session_t session, const char *str,
+		  unsigned no_cli_cert)
 {
 	size_t len = strnlen(str, 128);
 	int ret;
@@ -1027,22 +1085,21 @@ int check_command(gnutls_session_t session, const char *str, unsigned no_cli_cer
 		if (strncmp
 		    (str, "**REHANDSHAKE**",
 		     sizeof("**REHANDSHAKE**") - 1) == 0) {
-			fprintf(stderr,
-				"*** Sending rehandshake request\n");
+			fprintf(stderr, "*** Sending rehandshake request\n");
 			gnutls_rehandshake(session);
 			return 1;
 		} else if (strncmp
-		    (str, "**REAUTH**",
-		     sizeof("**REAUTH**") - 1) == 0) {
+			   (str, "**REAUTH**", sizeof("**REAUTH**") - 1) == 0) {
 			/* in case we have a re-auth cmd prepare for it */
 			if (no_cli_cert)
-				gnutls_certificate_server_set_request(session, GNUTLS_CERT_REQUIRE);
+				gnutls_certificate_server_set_request(session,
+								      GNUTLS_CERT_REQUIRE);
 
-			fprintf(stderr,
-				"*** Sending re-auth request\n");
+			fprintf(stderr, "*** Sending re-auth request\n");
 			do {
 				ret = gnutls_reauth(session, 0);
-			} while(ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED);
+			} while (ret == GNUTLS_E_AGAIN
+				 || ret == GNUTLS_E_INTERRUPTED);
 			if (ret < 0) {
 				fprintf(stderr, "reauth: %s\n",
 					gnutls_strerror(ret));
@@ -1141,7 +1198,8 @@ pin_callback(void *user, int attempt, const char *token_url,
 		env = "GNUTLS_SO_PIN";
 		desc = "security officer";
 		if (info && info->so_pin)
-			snprintf(password, sizeof(password), "%s", info->so_pin);
+			snprintf(password, sizeof(password), "%s",
+				 info->so_pin);
 	} else {
 		env = "GNUTLS_PIN";
 		desc = "user";
@@ -1164,8 +1222,7 @@ pin_callback(void *user, int attempt, const char *token_url,
 	}
 
 	if (cache > 0 && cached_url != NULL) {
-		if (token_url != NULL
-		    && strcmp(cached_url, token_url) == 0) {
+		if (token_url != NULL && strcmp(cached_url, token_url) == 0) {
 			if (strlen(cached_pin) >= pin_max) {
 				fprintf(stderr, "Too long PIN given\n");
 				exit(1);
@@ -1184,11 +1241,12 @@ pin_callback(void *user, int attempt, const char *token_url,
 
 	if (password[0] == 0) {
 		getenv_copy(password, sizeof(password), env);
-		if (password[0] == 0) /* compatibility */
+		if (password[0] == 0)	/* compatibility */
 			getenv_copy(password, sizeof(password), "GNUTLS_PIN");
 	}
 
-	if (password[0] == 0 && info != NULL && info->password != NULL && info->ask_pass == 0) {
+	if (password[0] == 0 && info != NULL && info->password != NULL
+	    && info->ask_pass == 0) {
 		if (strlen(info->password) < sizeof(password)) {
 			strcpy(password, info->password);
 		} else {
@@ -1197,22 +1255,27 @@ pin_callback(void *user, int attempt, const char *token_url,
 		}
 	}
 
-	if (password[0] == 0 && (info == NULL || info->batch == 0 || info->ask_pass != 0)) {
+	if (password[0] == 0
+	    && (info == NULL || info->batch == 0 || info->ask_pass != 0)) {
 		if (token_label && token_label[0] != 0) {
-			fprintf(stderr, "Token '%s' with URL '%s' ", token_label, token_url);
+			fprintf(stderr, "Token '%s' with URL '%s' ",
+				token_label, token_url);
 			fprintf(stderr, "requires %s PIN\n", desc);
 			getpass_copy(password, sizeof(password), "Enter PIN: ");
 		} else {
-			getpass_copy(password, sizeof(password), "Enter password: ");
+			getpass_copy(password, sizeof(password),
+				     "Enter password: ");
 		}
 
 	} else {
 		if (flags & GNUTLS_PIN_WRONG) {
 			if (token_label && token_label[0] != 0) {
-				fprintf(stderr, "Token '%s' with URL '%s' ", token_label, token_url);
+				fprintf(stderr, "Token '%s' with URL '%s' ",
+					token_label, token_url);
 				fprintf(stderr, "requires %s PIN\n", desc);
 			}
-			fprintf(stderr, "Cannot continue with a wrong password in the environment.\n");
+			fprintf(stderr,
+				"Cannot continue with a wrong password in the environment.\n");
 			exit(1);
 		}
 	}
@@ -1220,7 +1283,8 @@ pin_callback(void *user, int attempt, const char *token_url,
 	if (password[0] == 0 || password[0] == '\n') {
 		fprintf(stderr, "No PIN given.\n");
 		if (info != NULL && info->batch != 0) {
-			fprintf(stderr, "note: when operating in batch mode, set the GNUTLS_PIN or GNUTLS_SO_PIN environment variables\n");
+			fprintf(stderr,
+				"note: when operating in batch mode, set the GNUTLS_PIN or GNUTLS_SO_PIN environment variables\n");
 		}
 		exit(1);
 	}
@@ -1247,8 +1311,7 @@ pin_callback(void *user, int attempt, const char *token_url,
 
 #ifdef ENABLE_PKCS11
 
-static int
-token_callback(void *user, const char *label, const unsigned retry)
+static int token_callback(void *user, const char *label, const unsigned retry)
 {
 	char buf[32];
 	common_info_st *info = user;
@@ -1258,7 +1321,7 @@ token_callback(void *user, const char *label, const unsigned retry)
 		return -1;
 	}
 	log_msg(stdout, "Please insert token '%s' in slot and press enter\n",
-	       label);
+		label);
 	if (fgets(buf, sizeof(buf), stdin) == NULL) {
 		fprintf(stderr, "error reading input\n");
 		return -1;
@@ -1267,7 +1330,7 @@ token_callback(void *user, const char *label, const unsigned retry)
 	return 0;
 }
 
-void pkcs11_common(common_info_st *c)
+void pkcs11_common(common_info_st * c)
 {
 
 	gnutls_pkcs11_set_pin_function(pin_callback, c);
@@ -1292,8 +1355,7 @@ void sockets_init(void)
 #endif
 }
 
-
-int log_msg(FILE *file, const char *message, ...)
+int log_msg(FILE * file, const char *message, ...)
 {
 	va_list args;
 	int rv;
@@ -1307,7 +1369,7 @@ int log_msg(FILE *file, const char *message, ...)
 	return rv;
 }
 
-void log_set(FILE *file)
+void log_set(FILE * file)
 {
 	logfile = file;
 }
@@ -1316,7 +1378,7 @@ void log_set(FILE *file)
 #pragma GCC diagnostic ignored "-Wformat-y2k"
 /* This is very similar to ctime() but it does not force a newline.
  */
-char *simple_ctime(const time_t *t, char out[SIMPLE_CTIME_BUF_SIZE])
+char *simple_ctime(const time_t * t, char out[SIMPLE_CTIME_BUF_SIZE])
 {
 	struct tm tm;
 
@@ -1332,4 +1394,5 @@ char *simple_ctime(const time_t *t, char out[SIMPLE_CTIME_BUF_SIZE])
 	snprintf(out, SIMPLE_CTIME_BUF_SIZE, "[error]");
 	return out;
 }
+
 #pragma GCC diagnostic pop
