@@ -633,7 +633,7 @@ process_options (int argc, char **argv)
       if (!OPT_ARG_VERSION || !strcmp (OPT_ARG_VERSION, "c"))
         {
           const char str[] =
-            "p11tool 3.7.10\n"
+            "p11tool 3.8.0\n"
             "Copyright (C) 2000-2021 Free Software Foundation, and others\n"
             "This is free software. It is licensed for use, modification and\n"
             "redistribution under the terms of the GNU General Public License,\n"
@@ -646,14 +646,14 @@ process_options (int argc, char **argv)
       else if (!strcmp (OPT_ARG_VERSION, "v"))
         {
           const char str[] =
-            "p11tool 3.7.10\n";
+            "p11tool 3.8.0\n";
           fprintf (stdout, "%s", str);
           exit(0);
         }
       else if (!strcmp (OPT_ARG_VERSION, "n"))
         {
           const char str[] =
-            "p11tool 3.7.10\n"
+            "p11tool 3.8.0\n"
             "Copyright (C) 2000-2021 Free Software Foundation, and others\n"
             "This is free software. It is licensed for use, modification and\n"
             "redistribution under the terms of the GNU General Public License,\n"
@@ -765,7 +765,7 @@ usage (FILE *out, int status)
     "       --mark-wrap            Marks the generated key to be a wrapping key\n"
     "       --mark-trusted         Marks the object to be written as trusted\n"
     "				- prohibits the option 'mark-distrusted'\n"
-    "       --mark-distrusted      When retrieving objects, it requires the objects to be distrusted (blacklisted)\n"
+    "       --mark-distrusted      When retrieving objects, it requires the objects to be distrusted\n"
     "				- prohibits the option 'mark-trusted'\n"
     "       --mark-decrypt         Marks the object to be written for decryption\n"
     "       --mark-sign            Marks the object to be written for signature generation\n"
