@@ -16,12 +16,11 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GnuTLS; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * along with GnuTLS.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <stdio.h>
@@ -29,24 +28,25 @@
 
 #if defined(_WIN32) || !defined(ENABLE_HEARTBEAT)
 
-int main()
+int main(void)
 {
 	exit(77);
 }
 
 #else
 
-#include <string.h>
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
-#include <arpa/inet.h>
-#include <unistd.h>
-#include <gnutls/gnutls.h>
-#include <gnutls/dtls.h>
+# include <string.h>
+# include <sys/types.h>
+# include <netinet/in.h>
+# include <sys/socket.h>
+# include <sys/wait.h>
+# include <arpa/inet.h>
+# include <unistd.h>
+# include <signal.h>
+# include <gnutls/gnutls.h>
+# include <gnutls/dtls.h>
 
-#include "utils.h"
+# include "utils.h"
 
 static void terminate(void);
 
@@ -69,8 +69,7 @@ static pid_t child;
 /* A very basic DTLS client, with anonymous authentication, that exchanges heartbeats.
  */
 
-#define MAX_BUF 1024
-
+# define MAX_BUF 1024
 
 static void client(int fd, int server_init)
 {
@@ -130,8 +129,7 @@ static void client(int fd, int server_init)
 	if (!server_init) {
 		do {
 			ret =
-			    gnutls_record_recv(session, buffer,
-					       sizeof(buffer));
+			    gnutls_record_recv(session, buffer, sizeof(buffer));
 
 			if (ret == GNUTLS_E_HEARTBEAT_PING_RECEIVED) {
 				if (debug)
@@ -141,7 +139,7 @@ static void client(int fd, int server_init)
 				if (ret2 < 0) {
 					fail("pong: %s\n",
 					     gnutls_strerror(ret));
-					terminate();
+					exit(1);
 				}
 			}
 		}
@@ -150,7 +148,7 @@ static void client(int fd, int server_init)
 
 		if (ret < 0) {
 			fail("recv: %s\n", gnutls_strerror(ret));
-			terminate();
+			exit(1);
 		}
 	} else {
 		do {
@@ -161,12 +159,11 @@ static void client(int fd, int server_init)
 			if (debug)
 				success("Ping sent.\n");
 		}
-		while (ret == GNUTLS_E_AGAIN
-		       || ret == GNUTLS_E_INTERRUPTED);
+		while (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED);
 
 		if (ret < 0) {
 			fail("ping: %s\n", gnutls_strerror(ret));
-			terminate();
+			exit(1);
 		}
 	}
 
@@ -181,8 +178,6 @@ static void client(int fd, int server_init)
 	gnutls_global_deinit();
 }
 
-
-
 static gnutls_session_t initialize_tls_session(void)
 {
 	gnutls_session_t session;
@@ -204,7 +199,7 @@ static gnutls_session_t initialize_tls_session(void)
 static void terminate(void)
 {
 	int status;
-
+	assert(child);
 	kill(child, SIGTERM);
 	wait(&status);
 	exit(1);
@@ -257,8 +252,7 @@ static void server(int fd, int server_init)
 	if (server_init) {
 		do {
 			ret =
-			    gnutls_record_recv(session, buffer,
-					       sizeof(buffer));
+			    gnutls_record_recv(session, buffer, sizeof(buffer));
 
 			if (ret == GNUTLS_E_HEARTBEAT_PING_RECEIVED) {
 				if (debug)
@@ -283,8 +277,7 @@ static void server(int fd, int server_init)
 			if (debug)
 				success("Ping sent.\n");
 		}
-		while (ret == GNUTLS_E_AGAIN
-		       || ret == GNUTLS_E_INTERRUPTED);
+		while (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED);
 
 		if (ret < 0) {
 			fail("ping: %s\n", gnutls_strerror(ret));
@@ -312,6 +305,8 @@ static void start(int server_initiated)
 	int fd[2];
 	int ret;
 
+	signal(SIGPIPE, SIG_IGN);
+
 	ret = socketpair(AF_UNIX, SOCK_STREAM, 0, fd);
 	if (ret < 0) {
 		perror("socketpair");
