@@ -14,12 +14,11 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GnuTLS; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * along with GnuTLS.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+# include <config.h>
 #endif
 
 #include <stdio.h>
@@ -27,24 +26,24 @@
 
 #if defined(_WIN32) || !defined(ENABLE_HEARTBEAT)
 
-int main()
+int main(void)
 {
 	exit(77);
 }
 
 #else
 
-#include <string.h>
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
-#include <arpa/inet.h>
-#include <unistd.h>
-#include <gnutls/gnutls.h>
-#include <gnutls/dtls.h>
+# include <string.h>
+# include <sys/types.h>
+# include <netinet/in.h>
+# include <sys/socket.h>
+# include <sys/wait.h>
+# include <arpa/inet.h>
+# include <unistd.h>
+# include <gnutls/gnutls.h>
+# include <gnutls/dtls.h>
 
-#include "utils.h"
+# include "utils.h"
 
 static void terminate(void);
 
@@ -67,8 +66,8 @@ static pid_t child;
 /* A very basic DTLS client, with anonymous authentication, that exchanges heartbeats.
  */
 
-#define MAX_BUF 24*1024
-#define MAX_MTU 20*1024
+# define MAX_BUF 24*1024
+# define MAX_MTU 20*1024
 
 static void client(int fd)
 {
@@ -210,7 +209,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session) + 12);
+			       gnutls_dtls_get_data_mtu(session) + 12);
 	if (ret != GNUTLS_E_LARGE_PACKET) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -218,7 +217,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session) + 5048);
+			       gnutls_dtls_get_data_mtu(session) + 5048);
 	if (ret != GNUTLS_E_LARGE_PACKET) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -226,7 +225,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session));
+			       gnutls_dtls_get_data_mtu(session));
 	if (ret < 0) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -235,7 +234,7 @@ static void server(int fd)
 	gnutls_dtls_set_mtu(session, MAX_MTU);
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session) + 12);
+			       gnutls_dtls_get_data_mtu(session) + 12);
 	if (ret != GNUTLS_E_LARGE_PACKET) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -243,7 +242,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session) + 5048);
+			       gnutls_dtls_get_data_mtu(session) + 5048);
 	if (ret != GNUTLS_E_LARGE_PACKET) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -251,7 +250,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session));
+			       gnutls_dtls_get_data_mtu(session));
 	if (ret > 16384 || ret < 0) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -262,7 +261,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session));
+			       gnutls_dtls_get_data_mtu(session));
 	if (ret < 0) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -278,7 +277,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session) - 16);
+			       gnutls_dtls_get_data_mtu(session) - 16);
 	if (ret < 0) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
@@ -286,7 +285,7 @@ static void server(int fd)
 
 	ret =
 	    gnutls_record_send(session, buffer,
-				gnutls_dtls_get_data_mtu(session));
+			       gnutls_dtls_get_data_mtu(session));
 	if (ret != GNUTLS_E_LARGE_PACKET) {
 		terminate();
 		fail("send[%d]: %s\n", __LINE__, gnutls_strerror(ret));
